  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% a function to fit a thermal cloud 2-D
function [Analysis,Err] = Gauss1Dx1Dy(directory,number,InitParam,TOF)

%% F = image
Analysis=zeros(1,15);
a = directory;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%Camera settings%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cameranumber = 3;
d=  char(64+cameranumber);
e = '2';%horizontal imaging
xcal =14.32;  %camera resolution um/pix (horizontal imaging) Imaged area Rb
ycal =14.32;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%LoadingImages%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



if number < 10
    b = '\P000';
    filename = [a,b,num2str(number),d];       
    else if number < 100
        b = '\P00';
        filename = [a,b,num2str(number),d];            
        else
            b = '\P0';
            filename = [a,b,num2str(number),d];            
        end
end

atomsdata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'A',num2str(cameranumber-1),'.tga']);
noisedata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'N',num2str(cameranumber-1),'.tga']);
probedata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'P',num2str(cameranumber-1),'.tga']);
otherdata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'O',num2str(cameranumber-1),'.tga']);

if ~isempty(atomsdata)
    newdata=1;
    raw=(atomsdata-noisedata);
    probe=(probedata-noisedata);
    difference=raw-probe;
else
    newdata=0;
end

difference=max(-difference,0);


imA = atomsdata;
imP = probedata;
imN = noisedata;
imO = otherdata;

%%%%%%%%%%%%Max Optical Density%%%%%%%%%%%

MaxOD=5;
Foriginal=min(MaxOD,-log(max(0.00000001,(imA-imN)./(imP))));

% maxPic = max(max(Foriginal));
% minPic = min(min(Foriginal));
% imshow((Foriginal-minPic)/(maxPic-minPic)*256,jet(256),'Border','tight');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Crop image
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% initfigure = figure;
% [RefPic, rectIna] = imcrop((Foriginal-minPic)/(maxPic-minPic)*256,jet(256)); 
% close(initfigure);


%F = imcrop(Foriginal,[imagex imagey cropsizex cropsizey]); % for K as second image in Frame Transfer Mode

rectIna = [1000,200,200,600]

xmin1=rectIna(1);
ymin1=rectIna(2);
xwidth1=rectIna(3);
ywidth1=rectIna(4);

xmax1= xmin1 + xwidth1 ;
ymax1=ymin1 + ywidth1;


xmin2 = InitParam(8);
ymin2 = InitParam(9);
xmax2 = InitParam(10);
ymax2 = InitParam(11);



F = imcrop(Foriginal,[xmin1 ymin1  xwidth1 ywidth1]);
m = double(F);

maxPic = max(max(F));
minPic = min(min(F));
imshow((F-minPic)/(maxPic-minPic)*256,jet(256),'Border','tight');

% fprintf('\n\nCropped Image\n\n');
% disp(size(Foriginal));
% disp(size(m));
% 
% figure(1)
% subplot(1,1,1)
% imshow(m,[ ])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%1 D Fitting%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options = optimset('MaxFunEvals',100000,'TolX',0.000000001,'MaxIter',10000);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%atomic parameters%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h = 6.626*10.^(-34); %Js
hbarre = h/(2*pi); %Js
mAss =  84*1.67*10^(-27); %kg
kB =  1.3806503*10^(-23); %m^2 kg/s^2 K
lamda = 461*10.^(-9); %m
abscros = (3*(lamda.^2))./(2*pi); %m^2
Nparam = 1;


% Initial Values
Total = sum(sum(m)); %total optical density in the image
pODm = max(max(m)); %peak optical density in the image

[sizey, sizex] = size(m);
pODx = pODm*sizey;
pODy = pODm*sizex; %peak of optical density
offx = Total/sizex;
offy = Total/sizey;

% Integrated x profile
mx = sum(m);
minODx=min(min(mx));
maxODx=max(max(mx));
x1D = xmin1:1:xmax1;
lb1Dx = [-2*abs(minODx),0,xmin1,(xmax2-xmin2)/100];
ub1Dx = [2*abs(minODx),2*(maxODx-minODx),xmax1,2*(xmax1-xmin1)];
ip1Dx = [minODx,maxODx-minODx,0.5*(xmin1+xmax1),0.2*(xmax1-xmin1)];

[Results1Dx,resnormGauss1Dx,residualGauss1Dx,exitflag1Dx] = lsqcurvefit(@gaussian1Dfn,ip1Dx,x1D,mx,lb1Dx,ub1Dx,options);


% Integrated y profile
my = sum(m');
minODy=min(min(my));
maxODy=max(max(my));
y1D = ymin1:1:ymax1;
lb1Dy = [-2*abs(minODy),0,ymin1,(ymax2-ymin2)/100];
ub1Dy = [2*abs(minODy),2*(maxODy-minODy),ymax1,2*(ymax1-ymin1)];
ip1Dy = [minODy,maxODy-minODy,0.5*(ymin1+ymax1),0.2*(ymax1-ymin1)];

[Results1Dy,resnormGauss1Dy,residualGauss1Dy,exitflag1Dy] = lsqcurvefit(@gaussian1Dfn,ip1Dy,y1D,my,lb1Dy,ub1Dy,options);



