  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% a function to fit a thermal cloud 1-D by integrating each of the axis. This program outputs

% mx/my: Integrated x/y profile (for plotting)
% y1D/x1D: Integrated y/x profile x axis  (for plotting) 
% F OD data of the figure itself ( again for plotting)
% Results1Dy/Results1Dx: Output of the fitting program for the 1D gausiang
% expSigmax,expSigmay Calculated covariance

function [Results1Dx,Results1Dy,expSigmax,expSigmay,mx ,my,y1D,x1D,F] = MyGaussfit1D(directory,PictureNumber,params)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Loading image for fit 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


[opticalDensity] = GetPictureOD (directory,PictureNumber,params); % Load picture and calculate optical Density
Foriginal = opticalDensity;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                croping image for fit 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

MaxOD=5;
% Foriginal=min(MaxOD,-log(max(0.00000001,(imA)./(imP))));


rectIna = params.rectIna;


xmin1=rectIna(1);
ymin1=rectIna(2);
xwidth1=rectIna(3);
ywidth1=rectIna(4);

xmax1= xmin1 + xwidth1 ;
ymax1=ymin1 + ywidth1;



fig = figure(3);
F = imcrop(Foriginal,[xmin1 ymin1  xwidth1 ywidth1]);
m = double(F);

maxPic = max(max(Foriginal));
minPic = min(min(Foriginal));
im2Show =(Foriginal-minPic)/(maxPic-minPic)*256;
imshow(im2Show,jet(256),'Border','tight');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Display cropped image 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%1 D Fitting%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

options = optimset('MaxFunEvals',100000,'TolX',0.000000001,'MaxIter',10000);

% Initial Values
[sizey, sizex] = size(m);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% 1 D Fitting x axis %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Integrated x profile
mx = sum(m);
minODx=min(min(mx));
maxODx=max(max(mx));
x1D = xmin1:1:xmax1;
initialcenter = xmin1+sizex/2;
lb1Dx = [xmin1, 0      ,0        , minODx];
ub1Dx = [xmax1,xwidth1 ,10*maxODx, maxODx];
ip1Dx = [initialcenter,maxODx-minODx,0.5*(xmin1+xmax1),0.2*(xmax1-xmin1)];

[Results1Dx,resnormGauss1Dx,residualGauss1Dx,exitflag1Dx,output,lambda,J] = lsqcurvefit(@gaussian1Dfn,ip1Dx,x1D,mx,lb1Dx,ub1Dx,options);
 xCovariance = inv(J.'*J)*var(residualGauss1Dx);
[expSigmax,ExpCorrCx] = cov2corr(xCovariance);
% 
% testvalue = nlparci(Results1Dx,residualGauss1Dx,'jacobian',J)
% expSigmax=(testvalue(:,2)-testvalue(:,1))/4;
a = 0.5*((x1D - Results1Dx(1))/(Results1Dx(2))).^2;
y = Results1Dx(3)*exp(-a) + Results1Dx(4) ;
% 
% figure(1)
% scatter(x1D,mx)
% 
% hold on
% plot (x1D, y);
% a = ['\sigma','x','=',num2str(ycal*Results1Dx(2)),'\pm',num2str(ycal*expSigmax(2))]
% legend('Integrated x profile ',a)
% hold off


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% 1 D Fitting y axis %%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Integrated y profile
my = sum(m');
minODy=min(min(my));
maxODy=max(max(my));
y1D = ymin1:1:ymax1;
initialcenter = ymin1+sizey/2;
lb1Dy = [ymin1,0               ,0        ,minODy];
ub1Dy = [ymax1,ywidth1,10*maxODy ,maxODy];
ip1Dy = [initialcenter,maxODy-minODy,0.5*(ymin1+ymax1),0.2*(ymax1-ymin1)];

[Results1Dy,resnormGauss1Dy,residualGauss1Dy,exitflag1Dy,output,lambda,J] = lsqcurvefit(@gaussian1Dfn,ip1Dy,y1D,my,lb1Dy,ub1Dy,options);
 xCovariance = inv(J.'*J)*var(residualGauss1Dy);
[expSigmay,ExpCorrCx] = cov2corr(xCovariance);





