  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% a function to fit a thermal cloud 2-D
function [Analysis,Err] = Gauss2DFast(directory,number,InitParam,TOF)

%% F = image
Analysis=zeros(1,15);
a = directory;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%Camera settings%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cameranumber = 3;
d=  char(64+cameranumber);
e = '2';%horizontal imaging
xcal =14.32;  %camera resolution um/pix (horizontal imaging) Imaged area Rb
ycal =14.32;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%LoadingImages%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



if number < 10
    b = '\P000';
    filename = [a,b,num2str(number),d];       
    else if number < 100
        b = '\P00';
        filename = [a,b,num2str(number),d];            
        else
            b = '\P0';
            filename = [a,b,num2str(number),d];            
        end
end

atomsdata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'A',num2str(cameranumber-1),'.tga']);
noisedata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'N',num2str(cameranumber-1),'.tga']);
probedata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'P',num2str(cameranumber-1),'.tga']);
otherdata=loadtga([directory,'\P',num2str(number,'%04i'),char(64+cameranumber),'O',num2str(cameranumber-1),'.tga']);

if ~isempty(atomsdata)
    newdata=1;
    raw=(atomsdata-noisedata);
    probe=(probedata-noisedata);
    difference=raw-probe;
else
    newdata=0;
end

difference=max(-difference,0);


imA = atomsdata;
imP = probedata;
imN = noisedata;
imO = otherdata;

%%%%%%%%%%%%Max Optical Density%%%%%%%%%%%

MaxOD=5;
Foriginal=min(MaxOD,-log(max(0.00000001,(imA-imN)./(imP))));

% maxPic = max(max(Foriginal));
% minPic = min(min(Foriginal));
% imshow((Foriginal-minPic)/(maxPic-minPic)*256,jet(256),'Border','tight');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Crop image
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% initfigure = figure;
% maxPic = max(max(Foriginal));
% minPic = min(min(Foriginal));
% [RefPic, rectIna] = imcrop((Foriginal-minPic)/(maxPic-minPic)*256,jet(256)); 
% close(initfigure);


%F = imcrop(Foriginal,[imagex imagey cropsizex cropsizey]); % for K as second image in Frame Transfer Mode

rectIna = [763,12,746,989]

xmin1=rectIna(1);
ymin1=rectIna(2);
xwidth1=rectIna(3);
ywidth1=rectIna(4);

xmax1= xmin1 + xwidth1 ;
ymax1=ymin1 + ywidth1;


xmin2 = InitParam(8);
ymin2 = InitParam(9);
xmax2 = InitParam(10);
ymax2 = InitParam(11);



F = imcrop(Foriginal,[xmin1 ymin1  xwidth1 ywidth1]);
m = double(F);

maxPic = max(max(F));
minPic = min(min(F));
imshow((F-minPic)/(maxPic-minPic)*256,jet(256),'Border','tight');

% fprintf('\n\nCropped Image\n\n');
% disp(size(Foriginal));
% disp(size(m));
% 
% figure(1)
% subplot(1,1,1)
% imshow(m,[ ])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%1 D Fitting%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options = optimset('MaxFunEvals',100000,'TolX',0.000000001,'MaxIter',10000);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%atomic parameters%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h = 6.626*10.^(-34); %Js
hbarre = h/(2*pi); %Js
mAss =  84*1.67*10^(-27); %kg
kB =  1.3806503*10^(-23); %m^2 kg/s^2 K
lamda = 461*10.^(-9); %m
abscros = (3*(lamda.^2))./(2*pi); %m^2
Nparam = 1;


% Initial Values
Total = sum(sum(m)); %total optical density in the image
pODm = max(max(m)); %peak optical density in the image

[sizey, sizex] = size(m);
pODx = pODm*sizey;
pODy = pODm*sizex; %peak of optical density
offx = Total/sizex;
offy = Total/sizey;

% Integrated x profile
mx = sum(m);
minODx=min(min(mx));
maxODx=max(max(mx));
x1D = xmin1:1:xmax1;
lb1Dx = [-2*abs(minODx),0,xmin1,(xmax2-xmin2)/100];
ub1Dx = [2*abs(minODx),2*(maxODx-minODx),xmax1,2*(xmax1-xmin1)];
ip1Dx = [minODx,maxODx-minODx,0.5*(xmin1+xmax1),0.2*(xmax1-xmin1)];

[Results1Dx,resnormGauss1Dx,residualGauss1Dx,exitflag1Dx] = lsqcurvefit(@gaussian1Dfn,ip1Dx,x1D,mx,lb1Dx,ub1Dx,options);


% Integrated y profile
my = sum(m');
minODy=min(min(my));
maxODy=max(max(my));
y1D = ymin1:1:ymax1;
lb1Dy = [-2*abs(minODy),0,ymin1,(ymax2-ymin2)/100];
ub1Dy = [2*abs(minODy),2*(maxODy-minODy),ymax1,2*(ymax1-ymin1)];
ip1Dy = [minODy,maxODy-minODy,0.5*(ymin1+ymax1),0.2*(ymax1-ymin1)];

[Results1Dy,resnormGauss1Dy,residualGauss1Dy,exitflag1Dy] = lsqcurvefit(@gaussian1Dfn,ip1Dy,y1D,my,lb1Dy,ub1Dy,options);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2D fits
% Note: we must first prepare the X,Y, and m as 
%       vectors and not matrices; we cannot
%       use 2D Meshgrid's for the 2D fitting 
%       routine, i.e. the X,Y, and m must be 
%       vectors and not matrices.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[X,Y] = meshgrid(xmin1:xmax1,ymin1:ymax1);
xy2D(:,1) = X(:);
xy2D(:,2) = Y(:);
m2D = m(:);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%Meaning of FIT parameters%%%%%%%%%%%%%%%%
%%%%%%%%for  fitDoubleGauss2D(,) 2D fit%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% p(1)=Offset
% p(2)=>Signal Amplitude
% p(3)=>CenterX
% p(4)=>CenterY
% p(5)=>sigmaX
% p(6)=>sigmaY

%%%%%%%%%Parameter initialization%%%%%%%%%%%%%
initFITpar=[];
initFITpar(1)=0;
initFITpar(2)=10;
initFITpar(3)=Results1Dx(3);
initFITpar(4)=Results1Dy(3);
initFITpar(5)=Results1Dx(4);
initFITpar(6)=Results1Dy(4);

lb=[-2*abs(initFITpar(1)),0.1*initFITpar(2),0.8*initFITpar(3),0.8*initFITpar(4),0.8*initFITpar(5),0.8*initFITpar(6)]
ub=[10*(abs(initFITpar(1))+abs(initFITpar(2))),5*initFITpar(2),1.2*initFITpar(3),1.2*initFITpar(4),1.2*initFITpar(5),1.2*initFITpar(6)]

[resGauss2D,resnormGauss2D,residualGauss2D,exitflag2D] = lsqcurvefit(@(x,xdata) gaussian2Dfn(x,xdata),initFITpar,xy2D,m2D,lb,ub,options);

Results1Dx
Results1Dy

lb
ub
resGauss2D
% fprintf('\nSigmas\n');
% disp(Results1Dx(7));
% disp(Results1Dy(7));
% disp(DoubleGaussResults2D(10));
% disp(DoubleGaussResults2D(11));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%Evaluating Output%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%Nint%%%%%%%%%%

mbackground = m;
xmin = round(resGauss2D(3)-InitParam(3)+1-3*resGauss2D(5));
xmax = round(resGauss2D(3)-InitParam(3)+1+3*resGauss2D(5));
ymin = round(resGauss2D(4)-InitParam(4)+1-3*resGauss2D(6));
ymax = round(resGauss2D(4)-InitParam(4)+1+3*resGauss2D(6));

if(xmin<1)
    xmin=1;
end
if(ymin<1)
    ymin=1;
end
if(xmax>(xmax1-xmin1))
    xmax=xmax1-xmin1;
end
if(ymax>(ymax1-ymin1))
    ymax=ymax1-ymin1;
end


matoms = m(ymin:ymax,xmin:xmax);
[a, b] = size(mbackground);
[c, d] = size(matoms);
mbackground(ymin:ymax,xmin:xmax)=zeros(size(mbackground(ymin:ymax,xmin:xmax)));
avback = sum(sum(mbackground))/(a*b - c*d);
mbackground(ymin:ymax,xmin:xmax)=avback.*ones(size(mbackground(ymin:ymax,xmin:xmax)));
Background = sum(sum(mbackground));
NumberCal=(xcal*ycal*(10^(-12)))*Nparam/abscros;

Nint= NumberCal*(Total - Background);               %=Nint




% CoordAuxX = 1:1:sizex;
% CoordAuxY = 1:1:sizey;
% %-(rbecbimodal(2)-rbecbimodal(11))
% %-(rbecbimodal(1)-rbecbimodal(10))
% EnergyPerPartRaw = NumberCal*(xcal*ycal*10^(-12))^2 * ((CoordAuxY-10000).^2) * (m - mbackground) * ((CoordAuxX'-10000).^2) / Nint;
% EnergyPerPartFit = 2*pi*NumberCal*(xcalSr*10^(-6))^4*(rbecbimodal(5) * (rbecbimodal(3)*rbecbimodal(4))^3 + rbecbimodal(9) * (rbecbimodal(7)*rbecbimodal(8))^3 )/ (NGaussBimodal1 + NGaussBimodal2);
% 
% TeffRaw =  10^9*mSr*(wrSr*waSr*wzSr)^(2/3)/kB * EnergyPerPartRaw * Nint; % effective temperature, by 2nd order momentum calculation of "raw" image
% TeffFit = 10^9*mSr*(wrSr*waSr*wzSr)^(2/3)/kB *EnergyPerPartFit *(NGaussBimodal2+NGaussBimodal1); % effective temperature, by 2nd order momentum calculation of fit results
% 
% Tc = (10^9)*(hbar*((wrSr*waSr*wzSr).^(1/3))/kB).*(Nint/1.202).^(1/3);%critical Temperature, nk
%Tgaussx = 10^9*(mSr/(kB*(0.001*tof)^2)).*(0.000001*r(3).*xcalSr).^2;% hor axial Temperature from Gauss Fit, nk
%SigmaYGauss=0.000001*r(4).*xcalSr;
%Tgaussy = 10^9*(mSr/(kB*(0.001*tof)^2)).*(SigmaYGauss).^2;% vertical Temperature from Gauss Fit, nk
%TGaussYFiniteExpansion = 10^9*(mSr/kB)*(SigmaYGauss)^2 / ( 1/(wxyaverage^2) + (0.001*tof)^2);

% Tbimodalx1 = 10^9*(mSr/(kB*(0.001*tof)^2)).*(0.000001*rbecbimodal(3).*xcalSr).^2;% hor axial Temperature from bimodal Fit, Component 1, nk
% Tbimodaly1 = 10^9*(mSr/(kB*(0.001*tof)^2)).*(0.000001*rbecbimodal(4).*xcalSr).^2;% vertical Temperature from bimodal Fit, Component 1, nk

Tgauss1DX = 10^6*(mAss/(kB*(0.001*TOF)^2)).*(0.000001*Results1Dx(4).*xcal).^2;% hor axial Temperature from bimodal Fit, Component 2, nk
Tgauss1DY = 10^6*(mAss/(kB*(0.001*TOF)^2)).*(0.000001*Results1Dy(4).*ycal).^2;% vertical Temperature from bimodal Fit, Component 2, nk
Tgauss2DX = 10^6*(mAss/(kB*(0.001*TOF)^2)).*(0.000001*resGauss2D(5).*xcal).^2;% hor axial Temperature from bimodal Fit, Component 2, nk
Tgauss2DY = 10^6*(mAss/(kB*(0.001*TOF)^2)).*(0.000001*resGauss2D(6).*ycal).^2;% vertical Temperature from bimodal Fit, Component 2, nk
NGauss1D = NumberCal*(2*pi).*(resGauss2D(2).*Results1Dx(4).*Results1Dy(4));%atom number thermal bimodal dimple
NGauss2D = NumberCal*(2*pi).*(resGauss2D(2).*resGauss2D(5).*resGauss2D(6));%atom number thermal bimodal dimple

Analysis(8)=Tgauss1DX;
Analysis(9)=Tgauss1DY;
Analysis(10)=Tgauss2DX;
Analysis(11)=Tgauss2DY;
Analysis(12)=NGauss1D;
Analysis(13)=NGauss2D;
Analysis(14)=Nint;
% SigmaYGaussBi=0.000001*rbecbimodal(8).*xcalSr;
% TbimodalY2FiniteExpansion = 10^9*(mSr/kB)*(SigmaYGaussBi)^2 / ( 1/(wxyaverage^2) + (0.001*tof)^2);




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%NGauss%%%%%%%%%%%%%%

Analysis(1)= NumberCal*(2*pi*resGauss2D(5)*resGauss2D(6)*resGauss2D(2));  %=NGauss2D
Analysis(2)=NumberCal*(sqrt(2*pi)*Results1Dx(2)*Results1Dx(4));           %=NGauss1Dx
Analysis(3)=NumberCal*(sqrt(2*pi)*Results1Dy(2)*Results1Dy(4));           %=NGauss1Dy


% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%Sigmas%%%%%%%%%%%%%%%



Analysis(4)=Results1Dx(4)*xcal;                           %=xsigma1D
Analysis(5)=Results1Dy(4)*ycal;                           %=ysigma1D
Analysis(6)=resGauss2D(5)*xcal;                           %=xsigma2D
Analysis(7)=resGauss2D(6)*ycal;                           %=ysigma2D



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%Error Check%%%%%%%%%%%%%%%%%%%%%%%%

Err=zeros(1,6);

if( (max(Results1Dx - ub1Dx)>=0) || (min(Results1Dx - lb1Dx)<=0)) 
    Err(1)=1;
else
    Err(1)=0;
end


if( (max(Results1Dy - ub1Dy)>=0) || (min(Results1Dy - lb1Dy)<=0)) 
    Err(2)=1;
else
    Err(2)=0;
end

if( (max(resGauss2D - ub)>= 0) || (min(resGauss2D - lb)<=0)) 
    Err(3)=1;
else
    Err(3)=0;
end
Err(4)=exitflag1Dx;
Err(5)=exitflag1Dy;
Err(6)=exitflag2D;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%Plotting%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x=xmin1:0.1:xmax1;
y=ymin1:0.1:ymax1;
z=createGaussian2D(resGauss2D,X,Y);

figPlot=figure(2);
set(figPlot,'Name',['Picture number',num2str(number)]);
subplot(1,3,1);
scatter(x1D,mx);
hold on
plot(x,gaussian1Dfn(Results1Dx,x));
hold off
if(Err(1))
    title({'OD X-axis. Constraint Error!!',['Fit exit flag:',num2str(Err(4))]});
else
    title({'OD X-axis. Constraints OK!!',['Fit exit flag:',num2str(Err(4))]});
end


subplot(1,3,2);
scatter(y1D,my);
hold on
plot(y,gaussian1Dfn(Results1Dy,y));
hold off
if(Err(2))
    title({'OD Y-axis. Constraint Error!!',['Fit exit flag:',num2str(Err(5))]});
else
    title({'OD Y-axis. Constraints OK!!',['Fit exit flag:',num2str(Err(5))]});
end

subplot(1,3,3);
mesh(X,Y,z);
hold on
mesh(X,Y,m);
hold off
if(Err(3))
    title({'2D OD. Constraint Error!!',['Fit exit flag:',num2str(Err(6))]});
else
    title({'2D OD. Constraints OK!!',['Fit exit flag:',num2str(Err(6))]});
end


% fprintf('\nOutput\n');
% disp(Analysis(1:6));
% disp(Analysis(15));
% disp(Err);