(* ::Package:: *)

Quiet[BeginPackage["`BaseStrontium`","`BaseUsefulConstants`"], {General::obspkg, General::newpkg}]

mSr88=87.9056122571*au; (* kg, from wikipedia *)
mSr87=86.9088774970 *au; (* kg, from wikipedia *)
mSr86=85.9092607309 *au; (* kg, from wikipedia *)
mSr84=83.913425 *au; (* kg, from wikipedia *)

AbondancySr88 = 82.58 /100;
AbondancySr87 = 7.0 /100;
AbondancySr86 = 9.86 /100;
AbondancySr84 =  0.56 /100;
 (* see Ludlow thesis *)
\[Lambda]1S0to1P1 = 460.862369* 10^(-9); (* blue Mot *)
\[CapitalGamma]1S0to1P1 = 190.7* 10^(6); (* 190.7(3.0) according to ludlow 30.35 MHz *)
(*
M. Yasuda, T. Kishimoto, M. Takamoto, and H. Katori, Photoassociation spectroscopy
of 88Sr: Reconstruction of the wave function near the last node, Physical
Review A 73, 011403 (2006). 

S. B. Nagel, P. G. Mickelson, A. D. Saenz, Y. N. Martinez, Y. C. Chen, T. C.
Killian, P. Pellegrini, and R. Cote, Photoassociative spectroscopy at long range
in ultracold strontium, Physical Review Letters 94, 083004 (2005).
*)

\[Lambda]1D2to1P1 = 6.5* 10^(-6); (* spontaneous decay *)
\[CapitalGamma]1D2to1P1 = 2*Pi*621.;

\[Lambda]3P1to1D2 = 1.77* 10^(-6); (* spontaneous decay *)
\[CapitalGamma]3P1to1D2 = 2*Pi*350.;
\[Lambda]3P2to1D2 = 1.9* 10^(-6); (* spontaneous decay *)
\[CapitalGamma]3P2to1D2 = 2*Pi*175.;

\[Lambda]1S0to3P2 = 671* 10^(-9);
\[CapitalGamma]1S0to3P2 = 2*Pi*0.0003;
\[Lambda]1S0to3P1 = 689.4490984* 10^(-9);  (* red Mot *)
\[CapitalGamma]1S0to3P1 = 2*Pi*7.48* 10^(3); (* +/- 0.05, see onenote / The value of 7.48(1) if given in Nicholson et al., Nat. Commun. 6, 6896 (2015) *)
\[Lambda]1S0to3P0 = 698* 10^(-9);
\[CapitalGamma]1S0to3P0 = 2*Pi*0.00135; (* 87Sr only, latest paper from James Thompson (2020)  *)

\[Lambda]3P2to3D3 = 496.23* 10^(-9);  (* repump not used*)
\[CapitalGamma]3P2to3D3 = 2*Pi*9.8* 10^(6);
\[Lambda]3P2to3D2 = 496.79* 10^(-9);  (* repump *)
\[CapitalGamma]3P2to3D2 = 2*Pi*2.04* 10^(6);
\[Lambda]3P2to3D1 = 497.17* 10^(-9);  (* repump not used *)
\[CapitalGamma]3P2to3D1 = 2*Pi*0.21* 10^(3);

\[Lambda]3P1to5s4d3D2 = 487.25* 10^(-9);  (* repump not used *)
\[CapitalGamma]3P1to5s4d3D2 = 2*Pi*7.28134* 10^(6); (* A = 61 * 3/4~ 45.75 from Boyd thesis, NIST give A = 48.0 *)
\[Lambda]3P1to5s4d3D1 = 487.7436364819* 10^(-9);  (* repump not used *)
\[CapitalGamma]3P1to5s4d3D1 = 2*Pi*4.04519* 10^(6); (* A = 61 *5/12 ~ 25.4 from Boyd thesis. This is x2 too high because it doesn't take the mF dependent clebsch-gordan, NIST give A = 26.3 ; In the end, the transition strength for each mF is about 2MHz*)
\[Lambda]3P0to5s4d3D1 = 483.20* 10^(-9);  (* repump not used *)
\[CapitalGamma]3P0to5s4d3D1 = 2*Pi*33* 10^(6);

\[Lambda]3P1to5s5d3D2 = 397.039* 10^(-9);  (* repump not used *)
\[CapitalGamma]3P1to5s5d3D2 = 2*Pi*3.18708* 10^(6);  (* from Boyd A = 26.7 * 3/4 *)
\[Lambda]3P1to5s5d3D1 = 397.117* 10^(-9);  (* repump not used *)
\[CapitalGamma]3P1to5s5d3D1 = 2*Pi*1.7706* 10^(6);  (* from Boyd A = 26.7 *5/12  *)




(* NIST value for A: 8.9 - 27 - 42.7, corresponding to A= 79.32 *)
(* Boyd thesis gives A = 85 , Ludlow gives A = 75.4 *)
(* Theory A = 71.3, from H. G. C. Werij, C. H. Greene, C. E. Theodosiou, and A. Gallagher, Phys. Rev. A 46, 1248 (1992) and references therein *)
\[Lambda]3P0to3S1 = 679.1* 10^(-9);  (* repump *)
\[CapitalGamma]3P0to3S1 = 2*Pi*1.42* 10^(6); (* = A x 1/9 *)
E3P0to3S1 =(14317.507-29038.773)*100*cLum;
\[Lambda]3P1to3S1 = 688.02105* 10^(-9);  (* repump / transparency *)
\[CapitalGamma]3P1to3S1 = 2*Pi*3.81128* 10^(6); (*!!! this is x2 too high, because it doesn't take the mF dependent clebsch-gordan of the transition into account. In the end, the transitions strength for each mF is about 2MHz.
 = A x 2/9  ///
 check also litterature Kai Guo,Guangfu Wang and Anpei Ye J.Phys.B:At.Mol.Opt.Phys.43 (2010) 135004 *)
E3P1to3S1 =(14504.334-29038.773)*100*cLum;
\[Lambda]3P2to3S1 = 707.0* 10^(-9);  (* repump *)
\[CapitalGamma]3P2to3S1 = 2*Pi*6.80* 10^(6); (* = A x 5/9 *)
E3P2to3S1 =(14898.545-29038.773)*100*cLum;

\[Lambda]5s4d1D2to5s8p1P1 = 448.180255947677 *10^(-9)
\[CapitalGamma]5s4d1D2to5s8p1P1 = 2*Pi * 3.023*10^(6);

\[Lambda]Blue = \[Lambda]1S0to1P1;
\[CapitalGamma]Blue = \[CapitalGamma]1S0to1P1;
\[Lambda]Red = \[Lambda]1S0to3P1;
\[CapitalGamma]Red = \[CapitalGamma]1S0to3P1;
\[Lambda]Repump = \[Lambda]3P2to3D2;
\[CapitalGamma]Repump = \[CapitalGamma]3P2to3D2;

(* Scattering length *)
(* Mmostly taken from A. Stein, H. Kn\[ODoubleDot]ckel, and E.\[NonBreakingSpace]Tiemann, Eur. Phys. J. D\[NonBreakingSpace]57, 171 (2010) *)
a1S0iso88 = -1.9 * aB; (* +/- 0.4, / Stein gives -2.0(3)/ the value here is taken as weighted averaged with Y. N. Martinez de\[NonBreakingSpace]Escobar, P. G. Mickelson, P. Pellegrini, S. B. Nagel, A. Traverso, M. Yan, R. C\[OHat]t\[EAcute], and T. C. Killian, Phys. Rev. A\[NonBreakingSpace]78, 062708 (2008) *)
a1S0iso87 = 96.198 * aB;(* +/- 0.1 *) 
a1S0iso86 = 810.6 * aB;(* +/- 2.0, coming from J. A.\[NonBreakingSpace]Aman, J. C. Hill, R. Ding, K. R. A. Hazzard, T. C. Killian, and W. Y. Kon, Phys. Rev. A\[NonBreakingSpace]98, 053441 (2018) *) 
a1S0iso84 = 122.762 * aB; (* +/- 0.2 *)

a1S0iso88vs87 = 54.819* aB; (* +/- 0.1 *)
a1S0iso88vs86 = 97.374* aB; (* +/- 0.07 *)
a1S0iso88vs84 = 1658* aB; (* +/- 100 *)
a1S0iso87vs86 = 162.25* aB; (* +/- 0.3 *)
a1S0iso87vs84 = -57.61* aB; (* +/- 1.0 *)
a1S0iso86vs84 = 31.65* aB;(* +/- 0.3 *)

(* Facteurs de Land\[EAcute] *)
(* Bosons *)
g1S0Bosons = 0;

g1P1Bosons = 1;

g1D2Bosons = 1;

g3P0Bosons = 0;
g3P1Bosons = 3/2;
g3P2Bosons = 3/2;

g3D1Bosons = 1/2;
g3D2Bosons = 7/6;
g3D3Bosons = 4/3;

(* Fermions *)
g1SOF9sur2 = 200 /\[Mu]B; (*200 Hz/Gauss x mF *)

g1P1F7sur2 = -2/9;
g1P1F9sur2 = 4/99;
g1P1F11sur2 = 2/11;

g1D2F5sur2 = -4/7;
g1D2F7sur2 = -2/21;
g1D2F9sur2 = 4/33;
g1D2F11sur2 = 34/143;
g1D2F13sur2 = 4/13;

g3POF9sur2 = 200 /\[Mu]B; (*200 Hz/Gauss x mF *)

g3P1F7sur2 =-1/3;
g3P1F9sur2 =2/33;
g3P1F11sur2 =3/11;

g3P2F5sur2 =-6/7;
g3P2F7sur2 =-1/7;
g3P2F9sur2 =2/11;
g3P2F11sur2 =51/143;
g3P2F13sur2 =6/13;

TdopplerBlue = hbarre * \[CapitalGamma]1S0to1P1 / (2 * kB);
TdopplerRed = hbarre * \[CapitalGamma]1S0to3P1 / (2 * kB);

TrecoilBlue88 = ctePlanck^2 / (\[Lambda]1S0to1P1^2 * mSr88 * kB);
TrecoilBlue86 = ctePlanck^2 / (\[Lambda]1S0to1P1^2 * mSr86 * kB);
TrecoilBlue84 = ctePlanck^2 / (\[Lambda]1S0to1P1^2 * mSr84 * kB);
TrecoilRed88 = ctePlanck^2 / (\[Lambda]1S0to3P1^2 * mSr88 * kB);
TrecoilRed86 = ctePlanck^2 / (\[Lambda]1S0to3P1^2 * mSr86 * kB);
TrecoilRed84 = ctePlanck^2 / (\[Lambda]1S0to3P1^2 * mSr84 * kB);

VrecoilBlue88 = hbarre * (2*Pi/ \[Lambda]1S0to1P1) /  mSr88;
VrecoilBlue87 = hbarre * (2*Pi/ \[Lambda]1S0to1P1) /  mSr87;
VrecoilBlue86 = hbarre * (2*Pi/ \[Lambda]1S0to1P1) /  mSr86;
VrecoilBlue84 = hbarre * (2*Pi/ \[Lambda]1S0to1P1) /  mSr84;
VrecoilRed88 = hbarre * (2*Pi/ \[Lambda]1S0to3P1) /  mSr88;
VrecoilRed87 = hbarre * (2*Pi/ \[Lambda]1S0to3P1) /  mSr87;
VrecoilRed86 = hbarre * (2*Pi/ \[Lambda]1S0to3P1) /  mSr86;
VrecoilRed84 = hbarre * (2*Pi/ \[Lambda]1S0to3P1) /  mSr84;

ISatBlue =Pi *ctePlanck*cLum*\[CapitalGamma]1S0to1P1/(3 * \[Lambda]1S0to1P1^3);
ISatRed =Pi *ctePlanck*cLum*\[CapitalGamma]1S0to3P1/(3 * \[Lambda]1S0to3P1^3);

EndPackage[];



