function varargout=constructSSBEC6(Parameters,xx,yy)
% function [estimatedprofile,dimplefit,reservoirfit,crossoverfit,transportfit,BECfit]=constructSSBEC4(Parameters,xx,yy)

% Parameters(1)=DimpleN;
% Parameters(2)=DimpleWy;
% Parameters(3)=ReservoirN;
% Parameters(4)=ReservoirWy;
% Parameters(5)=ReservoirWx;
% Parameters(6)=CrossoverN;
% Parameters(7)=CrossoverWy;
% Parameters(8)=CrossoverWx;
% Parameters(9)=Dimplex;
% Parameters(10)=Dimpley;
% Parameters(11)=Crossoverx;
% Parameters(12)=Reservoirx;
% Parameters(13)=transportN;
% Parameters(14)=transportX;
% Parameters(15)=transportWx;
% Parameters(16)=transportY;
% Parameters(17)=transportWy;
% Parameters(18)=Background;
% Parameters(19)=BECN;
% Parameters(20)=BECwx;
% Parameters(21)=BECwy;
% Parameters(22)=BECX;
% Parameters(23)=BECY;

h = 6.626*10.^(-34); %Js
hbar = h/(2*pi); %Js
mSr =  84*1.67*10^(-27); %kg
% kB =  1.3806503*10^(-23); %m^2 kg/s^2 K
% lamdaSr = 461*10.^(-9); %m
% abscrosSr = (3*(lamdaSr.^2))./(2*pi); %m^2
a0 = 0.052917721086*10^-9;
% a8686 = 798*a0;
a8484 = 102.5*a0;
aScat = a8484;

t=18e-3;

% construct dimple profile

N=abs(Parameters(1)); % Parameters(1)=DimpleN;
x0=Parameters(9); % Parameters(9)=Dimplex;
y0=Parameters(10); % Parameters(10)=Dimpley;
W=Parameters(2); % Parameters(2)=DimpleWy;

dimplefit=exp(-((yy-y0)/W).^2-((xx-x0)/W).^2);
dimplefit=N*dimplefit/max(max(dimplefit));


% construct reservoir profile

N=abs(Parameters(3)); % Parameters(3)=ReservoirN;
x0=Parameters(12); % Parameters(12)=Reservoirx;
y0=Parameters(10); % Parameters(10)=Dimpley;
Wy=Parameters(4); % Parameters(4)=ReservoirWy;
Wx=Parameters(5); % Parameters(5)=ReservoirWx;

reservoirfit=exp(-((yy-y0)/Wy).^2-((xx-x0)/Wx).^2);
reservoirfit=N*reservoirfit/max(max(reservoirfit));

% construct crossover profile

N=abs(Parameters(6)); % Parameters(6)=CrossoverN;
x0=Parameters(11); % Parameters(11)=Crossoverx;
y0=Parameters(10); % Parameters(10)=Dimpley;
Wy=Parameters(7); % Parameters(7)=CrossoverWy;
Wx=Parameters(8); % Parameters(8)=CrossoverWx;

crossoverfit=exp(-((yy-y0)/Wy).^2-((xx-x0)/Wx).^2);
crossoverfit=N*crossoverfit/max(max(crossoverfit));

% construct transport guide profile

transportN=Parameters(13);
transportX=Parameters(14);
transportWx=Parameters(15);
transportY=Parameters(16);
transportWy=Parameters(17);
Background=Parameters(18);

% transportfit=transportN*exp(-((xx-transportX)/transportWx).^2).*...
%     exp(-((yy-transportY)/transportWy).^2)+Background;

transportfit=transportN./(1+exp(((xx-transportX)/transportWx))).*...
    exp(-((yy-transportY)/transportWy).^2)+Background;

% construct BEC profile

BECN=Parameters(19);

if BECN>0
    BECwx=Parameters(20);
    BECwy=Parameters(21);
    BECx0=Parameters(22);
    BECy0=Parameters(23);

    % From Pethick, Smith - Bose-Einstein Condensation in Dilute Gases
    % Expansion of a BEC from an isotropic trap:
    % with some creativity from BP
    %
    % pg 195
    % Also looked at https://arxiv.org/pdf/cond-mat/9904034.pdf pg 32 but did not use
    % see the "constructSSBEC5working.m" edition for this line
    
    omegaHO = (BECwx*BECwx*BECwy)^(1/3);
    aHO=(hbar/(mSr*omegaHO))^0.5;
    
    R_0x=(2/pi)^0.1*(BECN*aScat/aHO)^(1/5)*aHO*(omegaHO/BECwx);
    Rx=R_0x*(2/3*omegaHO^2*t^2)^0.5*1e3 * (omegaHO/BECwx)^(-5/2);

    R_0y=(2/pi)^0.1*(BECN*aScat/aHO)^(1/5)*aHO*omegaHO/BECwy;
    Ry=R_0y*(2/3*omegaHO^2*t^2)^0.5*1e3 * (omegaHO/BECwy)^(-5/2);
    
%      mu=hbar*omegaHO*(15*BECN*aScat/aHO)^(2/5)/2;
%     gScat = 4*pi*hbar^2*aScat/mSr;
    % n0 = mu/gScat;

    BECfit=max(0,1-(((yy-BECy0)/Ry).^2+((xx-BECx0)/Rx).^2));
    BECfit=BECfit*BECN/sum(sum(BECfit));
else
    BECfit=zeros(size(transportfit));
end

estimatedprofile=dimplefit+reservoirfit+crossoverfit+transportfit+BECfit;

if nargout>=1
    varargout{1}=estimatedprofile;
end
if nargout>=2
    varargout{2}=dimplefit;
end
if nargout>=3
    varargout{3}=reservoirfit;
end
if nargout>=4
    varargout{4}=crossoverfit;
end
if nargout>=5
    varargout{5}=transportfit;
end
if nargout>=6
    varargout{6}=BECfit;
end


% transport2Dsubsection=transport2D(:,SSBECfitparam.transportXrange1(1):SSBECfitparam.transportXrange1(2));
% transport2Ddatasubsection=imdata(:,SSBECfitparam.transportXrange1(1):SSBECfitparam.transportXrange1(2));
% 
% x0a(1)=1;
% x0a(2)=0;
% 
% % display('fitting...');
% x0a=fminsearch(@(x) modefit(x,transport2Dsubsection,transport2Ddatasubsection),x0a);
% 
% transportfit(7:8)=x0a(1:2);
% 
% imdata=imdata-transportfit(8);
% transport2D=transport2D*transportfit(7);
% imdata=imdata-transport2D;
% 
% estimatedprofile=dimplefit+reservoirfit+crossoverfit+transportfit;
% 
% figure(300);
% imagesc(estimatedprofile1);
% colorbar;
% colormap jet
% 
% figure(301);
% imagesc(estimatedprofile2);
% colorbar;
% colormap jet
% 
% figure(302);
% imagesc(estimatedprofile3);
% colorbar;
% colormap jet
% 
% figure(303);
% imagesc(estimatedprofile4);
% colorbar;
% colormap jet

end