  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% a function to fit a thermal cloud 1-D by integrating each of the axis. This program outputs

% mx/my: Integrated x/y profile (for plotting)
% y1D/x1D: Integrated y/x profile x axis  (for plotting) 
% Results1Dy/Results1Dx: Output of the fitting program for the 1D gausiang
% expSigmax,expSigmay Calculated covariance

function  MyGaussfit2D2D(directory,PictureNumber,params,Results1Dx,Results1Dy)




%% F = image
a = directory;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%Camera settings%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cameranumber = 3;
d=  char(64+cameranumber);
e = '2';%horizontal imaging
xcal =14.32;  %camera resolution um/pix (horizontal imaging) Imaged area Rb
ycal =14.32;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%LoadingImages%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



if PictureNumber < 10
    b = '\P000';
    filename = [a,b,num2str(PictureNumber),d];       
    else if PictureNumber < 100
        b = '\P00';
        filename = [a,b,num2str(PictureNumber),d];            
        else
            b = '\P0';
            filename = [a,b,num2str(PictureNumber),d];            
        end
end

atomsdata=loadtga([directory,'\P',num2str(PictureNumber,'%04i'),char(64+cameranumber),'A',num2str(cameranumber-1),'.tga']);
noisedata=loadtga([directory,'\P',num2str(PictureNumber,'%04i'),char(64+cameranumber),'N',num2str(cameranumber-1),'.tga']);
probedata=loadtga([directory,'\P',num2str(PictureNumber,'%04i'),char(64+cameranumber),'P',num2str(cameranumber-1),'.tga']);
otherdata=loadtga([directory,'\P',num2str(PictureNumber,'%04i'),char(64+cameranumber),'O',num2str(cameranumber-1),'.tga']);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%% END LoadingImages  %%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%  Calculate optical density %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if ~isempty(atomsdata)
    newdata=1;
    raw=(atomsdata-noisedata);
    probe=(probedata-noisedata);
    difference=raw-probe;
else
    newdata=0;
end

difference=max(-difference,0);


imA = atomsdata;
imP = probedata;
imN = noisedata;
imO = otherdata;


MaxOD=5;
Foriginal=min(MaxOD,-log(max(0.00000001,(imA)./(imP))));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%% end  Calculate optical density %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               croping image for fit 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 

% maxPic = max(max(Foriginal));
% minPic = min(min(Foriginal));
% imshow((Foriginal-minPic)/(maxPic-minPic)*256,jet(256),'Border','tight');
% 
% initfigure = figure;
% maxPic = max(max(Foriginal));
% minPic = min(min(Foriginal));
% [RefPic, rectIna] = imcrop((Foriginal-minPic)/(maxPic-minPic)*256,jet(256)); 
% close(initfigure);
% rectIna
% F = imcrop(Foriginal,[imagex imagey cropsizex cropsizey]); % for K as second image in Frame Transfer Mode

series =directory(end-2:end);
rectIna = params.rectIna;
SelectedColorMap= load('myCmap');

xmin1=rectIna(1);
ymin1=rectIna(2);
xwidth1=rectIna(3);
ywidth1=rectIna(4);

xmax1= xmin1 + xwidth1 ;
ymax1=ymin1 + ywidth1;



fig = figure(3)
F = imcrop(Foriginal,[xmin1 ymin1  xwidth1 ywidth1]);
m = double(F);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               END croping image for fit 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Display cropped image 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

maxPic = max(max(F));
minPic = min(min(F));
imshow((F-minPic)/(maxPic-minPic)*256,jet(256),'Border','tight');
%Load homemade colormap
a = SelectedColorMap;
colormap(gca, a.cmap);
colorbar('Ticks',[])
hold on
rectangle('Position',[0 337 15 2000/14.32 ] , 'FaceColor',[1 1 1])
hold off

% How to use.  Plot the figure, display the colorbar on the figure it self.
% Right click on it to arrive to interactive colormap.
%Save the colormap on a file cmap = colormap(gca); save('C:\Users\SrPal\Desktop\custumCmap','cmap')
% a= load('myCmap')
% colormap(gca, a.cmap);
% fprintf('\n\nCropped Image\n\n');
% disp(size(Foriginal));
% disp(size(m));
% 
% figure(1)
% subplot(1,1,1)
% imshow(m,[ ])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%            end Display cropped image 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%% 2 D Fitting %%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

options = optimset('MaxFunEvals',100000,'TolX',0.000000001,'MaxIter',10000);

Results1Dx,Results1Dy






% Initial Values
Total = sum(sum(m)); %total optical density in the image
pODm = max(max(m)); %peak optical density in the image
minOD=min(min(m));
[sizey, sizex] = size(m);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% 1 D Fitting x axis %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Integrated x profile
mx = sum(m);
minODx=min(min(mx));
maxODx=max(max(mx));
x1D = xmin1:1:xmax1;
y1D = ymin1:1:ymax1;
[X,Y] = meshgrid(x1D,y1D);
xdata = zeros(size(X,1),size(Y,2),2);
xdata(:,:,1) = X;
xdata(:,:,2) = Y;

lb2Dfn = [Results1Dx(1), Results1Dx(2) ,Results1Dy(1), Results1Dy(2),minOD,minOD]/5;
ub2Dfn = [Results1Dx(1), Results1Dx(2) ,Results1Dy(1), Results1Dy(2),pODm,pODm]*5;
ic2Dfn = [Results1Dx(1), Results1Dx(2) ,Results1Dy(1), Results1Dy(2),pODm,minOD];
[Results1Dx,resnormGauss1Dx,residualGauss1Dx,exitflag1Dx,output,lambda,J] = lsqcurvefit(@gaussian2Dfn2,ic2Dfn,xdata,m,lb2Dfn,ub2Dfn,options);


% xCovariance = inv(J.'*J)*var(residualGauss1Dx);
% [expSigmax,ExpCorrCx] = cov2corr(xCovariance);
% a = 0.5*((x1D - Results1Dx(1))/(Results1Dx(2))).^2;
% y = Results1Dx(3)*exp(-a) + Results1Dx(4) ;
% 
% figure(1)
% scatter(x1D,mx)
% 
% hold on
% plot (x1D, y);
% a = ['\sigma','x','=',num2str(ycal*Results1Dx(2)),'\pm',num2str(ycal*expSigmax(2))]
% legend('Integrated x profile ',a)
% hold off


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% 1 D Fitting y axis %%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Integrated y profile
my = sum(m');
minODy=min(min(my));
maxODy=max(max(my));
y1D = ymin1:1:ymax1;
initialcenter = ymin1+sizey/2
lb1Dy = [ymin1,0               ,0        ,minODy];
ub1Dy = [ymax1,ywidth1,10*maxODy ,maxODy];
ip1Dy = [initialcenter,maxODy-minODy,0.5*(ymin1+ymax1),0.2*(ymax1-ymin1)];

[Results2Dy,resnormGauss1Dy,residualGauss1Dy,exitflag1Dy,output,lambda,J] = lsqcurvefit(@gaussian2Dfn,ip1Dy,y1D,my,lb1Dy,ub1Dy,options);
 xCovariance = inv(J.'*J)*var(residualGauss1Dy);
[expSigmay,ExpCorrCx] = cov2corr(xCovariance);





