
function [atomNumberTab,effTemperatureTab,effTemperature1DXTab,effTemperature1DYTab,centerOfMassX,centerOfMassY ,Spreadx,Spready ] = calculateExperimentalValues (params,filename,croppedPic)
    
    global ctePlanck hbarre cLum kB aB MuB hartree Mu0 Epsilon0 au eElec gForce Debye Na
    global ctePlanckOverAu auOverCtePlanck ctePlanckOverkB kBOverCtePlanck auOverkB kBOverAu hbarreOverAu hbarreOverkB hbarreOverMuB MuBOverHbarre
    global mSr88 mSr87 mSr86 mSr84
    
    UsefulConstants;
    BaseStrontium;
    if ( ~isempty(strfind(filename, 'AA'))) % USE MOT side camera calibration
        xCalSr = 4.48 * 10^(-6);  %camera resolution m/pix
        yCalSr = 4.48 * 10^(-6);
    elseif  ( ~isempty(strfind(filename, 'BA'))) % USE MOT TOP camera calibration
        xCalSr = 4 * 10^(-6);  %camera resolution m/pix
        yCalSr = 4 * 10^(-6);  
    elseif  ( ~isempty(strfind(filename, 'CA'))) % USE Capture MOT
        xCalSr = 14.32 * 10^(-6);  %camera resolution m/pix
        yCalSr = 14.32 * 10^(-6);
    end
    
    wxSr = 2 * pi * 100; %estimation of the trapping frequency
    wySr = 2 * pi * 200;
    mAssSr = mSr88;
    lamdaSr = 461. * 10^(-9); %(in m)   

    atomNumberTab= [];
    effTemperatureTab= [];
    effTemperature1DXTab= [];
    effTemperature1DYTab= [];

    
    
    % calculate the atom number
    cte = 1 + 4*params.lightDetunning^2;
    absCrossSr = (3*(lamdaSr.^2))./(2*pi)/cte; % (m^2)
    numberCal = (yCalSr*xCalSr) / absCrossSr;
    TotalMatNb = sum(sum(croppedPic)); %total optical density in the image

    atomNumber = TotalMatNb * numberCal;
    % calculate the center of mass in x and y
    [sizey, sizex] = size(croppedPic);
    CoordAuxX = 1:1:sizex;
    CoordAuxY = 1:1:sizey;
    croppedPicX = sum(croppedPic,1);
    croppedPicY = sum(croppedPic,2)';
    centerOfMassX = croppedPicX * CoordAuxX' /TotalMatNb ;
    centerOfMassY = croppedPicY * CoordAuxY' /TotalMatNb ;

    %calculate effective temperature                
    EnergyPerPartRaw = (xCalSr * yCalSr)^2 * ((CoordAuxY-centerOfMassY).^2) * (croppedPic) * ((CoordAuxX'-centerOfMassX).^2) / TotalMatNb; % effective temperature, by 2nd order momentum calculation of image
    effTemperature = 4 / pi * mAssSr * (wxSr*wySr)^(2/2)* auOverkB * EnergyPerPartRaw * atomNumber / 2; % effective temperature, by 2nd order momentum calculation of image

    EnergyPerPartRaw1DX = (xCalSr)^3 * numberCal *((CoordAuxX-centerOfMassX).^2) * croppedPicX' / sizey / atomNumber; % effective temperature, by 2nd order momentum calculation of image
    effTemperature1DX =  4 / pi * mAssSr * wxSr^2 * auOverkB * EnergyPerPartRaw1DX * atomNumber; % effective temperature, by 2nd order momentum calculation of image

    EnergyPerPartRaw1DY = (yCalSr)^3 * numberCal *((CoordAuxY-centerOfMassY).^2) * croppedPicY' / sizex / atomNumber; % effective temperature, by 2nd order momentum calculation of image
    effTemperature1DY =  4 / pi * mAssSr * wySr^2 * auOverkB * EnergyPerPartRaw1DY * atomNumber; % effective temperature, by 2nd order momentum calculation of image

    %Calculate spread in px
     Spreadx = sum((-centerOfMassX.^2 + (croppedPicX.* CoordAuxX).^2).^0.5)/TotalMatNb;
     Spready =sum  ( (-centerOfMassY.^2 + (croppedPicY.* CoordAuxY).^2).^0.5)/TotalMatNb;
     
    display(['Evaluating ', filename]);
%     fprintf('Number of atoms: %.0f\n', atomNumber);
%     fprintf('Temperature: %.3f muK\n', effTemperature * 10^6);
%     fprintf('Temperature 1D in X: %.3f muK\n', effTemperature1DX * 10^6);
%     fprintf('Temperature 1D in Y: %.3f muK\n', effTemperature1DY * 10^6);




    atomNumberTab = [atomNumberTab, atomNumber];
    effTemperatureTab = [effTemperatureTab, effTemperature];
    effTemperature1DXTab = [effTemperature1DXTab, effTemperature1DX];
    effTemperature1DYTab = [effTemperature1DYTab, effTemperature1DY];
   
end