classdef DataClass
   properties
        Populations;
        time;
        TransferAtoms;
        Params
   end
   methods

    function obj = DataClass(params)     
        obj.time = params.OutputSimulation.x;
        obj.Populations = params.OutputSimulation.y;
        obj.Params = params;
    end
    
    function TransferAtoms = getTransferAtoms(obj,time)
            params = obj.Params;          
            Operators = OperatorClass(params) ;      
%              obj.Populations(:,200:400) = 0;
            Rho3 = @(index) reshape( obj.Populations(index,:),[] , params.InternalStates);
            Rho2 = @(index) sum(Rho3(index)');
            yvalues = Rho2(time);
            TransferAtoms = sum(yvalues(end-3:end));
    end
    function Momentum = getMomentum(obj,time)
            params = obj.Params;          
            Operators = OperatorClass(params) ;      
            Pmat = Operators.Pmat;
            
%              obj.Populatio,200:400) = 0;
            Rho = @(index) diag( obj.Populations(index,:));
            p = @(index) trace(Pmat*Rho(index));

            Momentum =p(time);
    end    function Momentumsq = getMomentumsq(obj,time)
            params = obj.Params;          
            Operators = OperatorClass(params) ;      
            Pmat = Operators.Pmat;
            Pmatsq = Pmat*Pmat;
            
%              obj.Populatio,200:400) = 0;
            Rho = @(index) diag( obj.Populations(index,:));
            psq = @(index) trace(Pmatsq*Rho(index));

            Momentumsq =psq(time);
    end
    function  plotTemperature (obj,time)
        params = obj.Params; 
        paramsSI = params.getSIUnits;
        
        Operators = OperatorClass(params)  
        Pmat = Operators.Pmat;
        
        %%Ploting temperature after sweeps
        Rho3 = @(index) reshape(  obj.Populations(index,:),[] , params.InternalStates);
        figure
        Rho2 = @(index) sum(Rho3(index)');
        Pmat2 =  diag(Pmat);
        xvalues = Pmat2(1: params.pstates);
        yvalues = Rho2(time)
        yavlues2 = Rho2(1);
        hold on
        scatter(xvalues,yvalues);
        scatter(xvalues,yavlues2);
        hold off
        plottitle = ['frequency = ',num2str(1/paramsSI.Ts) ,'rabi frequency', num2str(paramsSI.Omega/2/pi)]
        title (plottitle);

        
    end
        
     function [Pvals,MomentumDistribution]  =  getMomentumDistribution (obj,time)
        params = obj.Params; 
        paramsSI = params.getSIUnits;
        
        Operators = OperatorClass(params)  
        Pmat = Operators.Pmat;
        
        %%Ploting temperature after sweeps
        Rho3 = @(index) reshape(  obj.Populations(index,:),[] , params.InternalStates);
        Rho2 = @(index) sum(Rho3(index)');
        Pmat2 =  diag(Pmat);
        xvalues = Pmat2(1: params.pstates);
        yvalues = Rho2(time)

        MomentumDistribution =     yvalues;
        Pvals = xvalues;
        end
        
        function plotMomentumvsTime(obj)
                params =obj.Params;
                paramsSI = params.getSIUnits;
                Operators = OperatorClass(params)  
                Pmat = Operators.Pmat;
                %%Plot population of states
                P = params.OutputSimulation;
                time = P.x/paramsSI.Gamma;
                endValue = length(time);
                Rho = @(index) diag(P.y(index,:));

                diagsum = sum(diag(Rho(999)))
                %%Ploting Pavg vs time
                figure
                time = P.x/paramsSI.Gamma;
                ydata=arrayfun(@(index)  trace(Rho(index)*Pmat),(1:10:endValue)) ;
                xdata = time(1:10:endValue)
                hold on
                scatter(xdata,ydata)
                hold off
                plottitle = ['frequency = ',num2str(1/paramsSI.Ts) ,'rabi frequency', num2str(paramsSI.Omega)]
                title (plottitle);

        end

        function plotMfStatesvsTIme (obj)
        params = obj.Params; 
        paramsSI = params.getSIUnits;

            %%Ploting mf states over time
        figure
        endValue = size(obj.time/paramsSI.Gamma,1);
        Rho4 = @(index) sum(reshape(  obj.Populations(index,:),[] , params.InternalStates));
        for i = 1:endValue 
            yvalue = Rho4(i);
            yadata(:,i) = yvalue(1:10);
        end
        
%         trapped = sum(yadata);
        legendsPlot = {};
        mf = linspace(-params.Fp,params.Fp,params.InternalStates/2)
        for i = mf  
            stringplot ={num2str(i)}
            legendsPlot = [legendsPlot,stringplot];
        end
        hold on
        plot(obj.time/paramsSI.Gamma,yadata)
        legend(legendsPlot)
%         plot(obj.time/paramsSI.Gamma,trapped);
        hold off
        legend(legendsPlot)
        plottitle = ['frequency = ',num2str(1/paramsSI.Ts/1000),' [KHz] ' ,'\Omega = ', num2str(paramsSI.Omega/2/pi/1000),' [KHz] ', ' p = ',num2str(params.p),' [hbar k]']
        title (plottitle);
        end
        
        function force = getAvgForceAfterOneSweep(obj)
            params = obj.Params;
            Operators = OperatorClass(params)
            parmasSI = params.getSIUnits;
            frequnecySweep = 1/parmasSI.Ts;
            %%Plot population of states
            P = params.OutputSimulation;
            time = P.x/parmasSI.Gamma;
            Pmat = Operators.Pmat;
            %Plots average momentum over time
            Rho = @(index) diag(P.y(index,:));
            Pavg2 = @(index)  trace(Rho(index)*Pmat);

            

            xdata = time';
            index = 1:5:999;
            xdata = xdata(index);
            pt = arrayfun(Pavg2,index);
            pol = polyfit(xdata,pt,1);

            force = pol(1);
        end
        
        function polvector = getMFdistribution(obj,time)
            params = obj.Params;
            P = params.OutputSimulation;
            Rho = @(index) diag(P.y(index,:));
            Rho4 = @(index) sum(reshape( P.y(index,:),[] , params.InternalStates));
            polvector = Rho4(time);
            

        end
   end
   

   
end