

function [ Hi ] = MakeInteractingHamiltonian (params)
    FullCouplingMatrix = MakeFullCouplingMatrix (params);
    
    for i = 1:params.InternalStates
        for j = 1:params.InternalStates
            if (i ~= j )
                if (i > j )
                    Hi{i,j} =   MakePstatesCouplingMatrix( params, FullCouplingMatrix(j,i) );
                else
                    Hi{i,j} =   MakePstatesCouplingMatrix( params, FullCouplingMatrix(i,j) );
                end
            else
                Hi{i,j} =  zeros(params.pstates);
            end
            
        end
    end
    Hi = params.hbar*cell2mat(Hi);
    
end

function FullCouplingMatrix = MakeFullCouplingMatrix (params)
%% This matrix defines how states couple to each other.  And the strenght
    OmegaMatrix = GetStateCouplingMatrix(params);
    zerosM = zeros(params.InternalStates/2);
    FullCouplingMatrix=[zerosM,OmegaMatrix;OmegaMatrix.',zerosM];

end

function [OmegaMatrix] = GetStateCouplingMatrix (params)
InternalStates = (params.F + params.Fp)*2 + 2;
Fp = params.Fp;
F  = params.F;
Omega = params.Omega;
Poltab = params.Poltab;
    for i = 1:(InternalStates/2)
        for j = 1:(InternalStates/2)
            if ( i == j-1 )
                OmegaMatrix(i,j) = Omega*Poltab(1)*StrenghtSigmaPlus(i,F,Fp);
            elseif ( i == j )
                OmegaMatrix(i,j) = Omega*Poltab(2)*StrenghtPi(i,F,Fp);
            elseif (i == j + 1)
                OmegaMatrix(i,j) = Omega*Poltab(3)*StrenghtSigmaMinus(i,F,Fp);
            end
        end
    end
    OmegaMatrix =  1/2*OmegaMatrix;
end

function [ Hod ] =  MakePstatesCouplingMatrix (params,Omega)
    %%Defines how two states couple in momentum. 

    C=Omega;

    for i = 1:params.pstates
        for j = 1:params.pstates
            if i == j + 1 | i == j - 1 ;
              Hod ( i , j ) = 1;             
            end
        end
    end
    Hod = C * Hod;
end





function [StrenghtPiTransition ] = StrenghtPi (state,F,Fp)
    if (F==0 & Fp==0)
       StrenghtPiTransition = 1;
    else
       m1 = -F + state - 1;
       m2 =  -F + state - 1;
       StrenghtPiTransition = ClebschGordan(F,m1,1,0,Fp,m2);

    end
end

function [ StrenghtSigmaPlus ] = StrenghtSigmaPlus (state,F,Fp)
    if (F==0 & Fp==0)
       StrenghtSigmaPlus = 1;
    else
       m1 = -F + state - 1;
       m2 =  m1 +1;
       StrenghtSigmaPlus = ClebschGordan(F,m1,1,1,Fp,m2);

    end
end

function [ StrenghtSigmaMinus ] = StrenghtSigmaMinus (state, F,Fp)
    if (F==0 & Fp==0)
       StrenghtSigmaMinus = 1;
    else
       m1 = -F + state - 1;
       m2 =  m1 - 1;
       StrenghtSigmaMinus = ClebschGordan(F,m1,1,-1,Fp,m2);

    end
end

