classdef OperatorClass
   properties
       Pmat;%Momentum Operator       
       Hnot; % Non interacting hamiltonian 
       Hi; % Interacting hamiltonina ( time independent part ) 
       H ; % Full time independent hamiltonian;
       Ht; % Time dependent part of the hamiltonian ( The part with the deuting )
       L; %Liouvilian ( decay rate), 
       rho; %Density matrix
       
   end
   methods

    function obj = OperatorClass(params)     
        obj.Pmat = MakeMomentumOperator(obj,params);
        obj.Hnot = MakeHnot (params);
        obj.Hi   = MakeInteractingHamiltonian (params);
        obj.H    = obj.Hnot + obj.Hi ;
        obj.Ht =   getHt(obj,params,1); 
    end
    function Pmat = MakeMomentumOperator(obj,params)
        i= 1:params.pstates;
        pdiag = params.p-params.hbar*(i-1)*params.k;
        pdiag = repmat(pdiag,1,params.InternalStates);
        Pmat = diag(pdiag);
      
    end      
    function L = MakeL(obj,params)
        %Previous version of Liovillian construction
        [K,sigmamult2,v,vfn,sigmamult2diag,mat] = ConstructDecayOperators (params); 
        rhoMat = obj.rho;


        prefactor = diag(rhoMat)'* vfn(:,1:size(v,2));
        result = cellfun(@times, sigmamult2, num2cell(prefactor), 'UniformOutput', false);
        [ii, jj, vv] = find(vertcat(result{:}));
        ii2 = mod(ii-1, params.ProblemDim) + 1;
        L = sparse(ii2, jj, vv , params.ProblemDim , params.ProblemDim );
        L = L + rhoMat*K +K*rhoMat;

    end
    
    function L = MakeL2(obj,params)
        rhoMat = obj.rho;
         [K,sigmamult2diag,v,vfn,sigmamult2,mat] = ConstructDecayOperators (params); 

        %Faster optimized solution for making the Louvillian operator  
        prefactor2 = vfn(:,1:size(v,2))'*diag(rhoMat) ;
        L = diag(sum(bsxfun(@times,sigmamult2,prefactor2),1)) + rhoMat.*mat;


    end
    
    
    function Ht = getHt(obj,params,delta) 
       a=params.ProblemDim/2;
       Ht = delta * params.hbar*0.5*sparse( [eye(a),zeros(a);zeros(a),-eye(a)]); %We add the time dependency inside the obe

    end
   end
   

   
end