function ic = getInitialCondition(params)
    nground = params.F*2 +1;
    if (strcmp(params.PopulationType,'Thermal'))
        ic = getThermalPopulation (params);
    elseif (strcmp(params.PopulationType,'1State111'))
        ic = get1State111 (params);
    elseif (strcmp(params.PopulationType,'HalfThermal'))
        ic = getHalfThermal (params);
    elseif (strcmp(params.PopulationType,'HalfThermalv2'))
        ic = getHalfThermalv2 (params);
    elseif (strcmp(params.PopulationType,'1State11'))
        ic = zeros(1 , (params.ProblemDim)*(params.ProblemDim + 1)/2 ); % I only need uper triangular part of density Matrix.
        ic(1,1) = 1;
    elseif (strcmp(params.PopulationType,'Unpolarized'))
        auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
        for i = 1: nground
             auxic((i-1)*params.pstates +1,(i-1)*params.pstates +1) = 1/nground;
            
        end
        ic =  auxic(tril(true(size(auxic))));
    elseif (strcmp(params.PopulationType,'Unpolarizedv2'))
        auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
        for i = 1: nground
            index=(i-1)*params.pstates + fix(params.pstates/2) +1;
             auxic(index,index) = 1/nground;
            
        end
        ic =  auxic(tril(true(size(auxic))));
    elseif (strcmp(params.PopulationType,'Unpolarizedv5'))
        auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
        for i = 1: nground*2
            index=(i-1)*params.pstates + fix(params.pstates/2) +1;
             auxic(index,index) = 1/nground;
            
        end
        ic =  auxic(tril(true(size(auxic))));
         elseif (strcmp(params.PopulationType,'NegativeMfStates'))
        auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
        for i = 1: fix(nground/2)
            index=(i-1)*params.pstates + fix(params.pstates/2) +1;
             auxic(index,index) = 1/nground/2;
            
        end
        ic =  auxic(tril(true(size(auxic))));
    elseif (strcmp(params.PopulationType,'1statev2'))
        auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
        index=fix(params.pstates/2)+1;
        auxic(index,index) = 1;           
        ic =  auxic(tril(true(size(auxic))));        
    elseif (strcmp(params.PopulationType,'customPolarization'))
        auxic = diag(zeros((params.ProblemDim) , (params.ProblemDim ) ));
        polvector =  params.polVector;
        
        for i = 1:length(polvector)
            index=(i-1)*params.pstates + fix(params.pstates/2) +1;
            auxic(index)  = polvector (i);
        end
        auxic = auxic/sum(auxic);
        auxic = diag(auxic);
        ic =  auxic(tril(true(size(auxic))));
        
     elseif (strcmp(params.PopulationType,'customPolarizationv2'))
        auxic = diag(zeros((params.ProblemDim) , (params.ProblemDim ) ));
        polvector =  params.polVector;
        
        for i = 1:length(polvector)
            index=(i-1)*params.pstates +1;
            auxic(index)  = polvector (i);
        end
        auxic = auxic/sum(auxic);
        auxic = diag(auxic);
        ic =  auxic(tril(true(size(auxic))));
    elseif (strcmp(params.PopulationType,'Unpolarizedv3'))
        auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
        for i = 1: nground
            index = (i-1)*params.pstates +1
             auxic(index,index ) = 1/nground/5;
             auxic(index+1,index+1 )= 1/nground/5;
             auxic(index+2,index+2 )= 1/nground/5;
             auxic(index+1,index+3 )= 1/nground/5;
             auxic(index+2,index+4 )= 1/nground/5;
        end
        ic =  auxic(tril(true(size(auxic))));
    elseif (strcmp(params.PopulationType,'customPolarizationv3'))
        auxic = diag(zeros((params.ProblemDim) , (params.ProblemDim ) ));
        
        dataic = load(params.savenameic);
        Dataic = DataClass(dataic.saveVar);           
        polvector = Dataic.getMFdistribution (999);

        
        for i = 1:length(polvector)
            index=(i-1)*params.pstates + fix(params.pstates/2) +1;
            auxic(index)  = polvector (i);
        end
        auxic = auxic/sum(auxic);
        auxic = diag(auxic);
        ic =  auxic(tril(true(size(auxic))));
    end
    
    

end
function ic = get1State111(params)
auxic = zeros((params.ProblemDim) , (params.ProblemDim ) ); % I only need uper triangular part of density Matrix.
auxic(params.pstates,params.pstates) = 1;
 ic =  auxic(tril(true(size(auxic))));  
end
function ic = getHalfThermal  (params)
    m = 87.62*1.66054*10^-27; %Kg
    T = params.Temperature;
    Kb = 1.38064852 * 10^(-23);
    hbaraux = 1.0545718*10^-34; %Joules*Second
    kaux = (2*pi/689)*10^9;%Meters^-1
 
    
    
    p = (-(0:(params.pstates-1))) + params.p;
    Pbtz=p(p>=0);
    kz=0*p(p<0);
    K = -(Pbtz*hbaraux*kaux).^2/(m*2*Kb*T);    
    ic =  exp(K);
    ic = [ic,kz];
    hold on
    figure
    plot(p,ic)
    hold off
    if (params.Fp ==0 & params.F ==0)
        ic = ic/abs(sum(ic));
        ceros= zeros(1,params.pstates);
        ic = diag([ic,ceros]);
        ic = ic(tril(true(size(ic))));
        ic  = ic';
    else
        ic = repmat(ic,1,params.InternalStates/2);
        ic = ic/sum(ic);
        ceros= zeros(1,params.ProblemDim/2);
        ic = diag([ic,ceros]);
        ic = ic(tril(true(size(ic))));
        ic  = ic';
       
    end
    
end
function ic = getHalfThermalv2  (params)
    m = 87.62*1.66054*10^-27; %Kg
    T = params.Temperature;
    Kb = 1.38064852 * 10^(-23);
    hbaraux = 1.0545718*10^-34; %Joules*Second
    kaux = (2*pi/689)*10^9;%Meters^-1
 
    
    
    p = (-(0:(params.pstates-1))) + params.p;
    Pbtz=p(p>=0);
    kz=0*p(p<0);
    K = -(Pbtz*hbaraux*kaux).^2/(m*2*Kb*T);    
    ic =  exp(K);
    ic = [ic,kz];
    hold on
    figure
    plot(p,ic)
    ic (1:3) = 0;
    hold off
    if (params.Fp ==0 & params.F ==0)
        ic = ic/abs(sum(ic));
        ceros= zeros(1,params.pstates);
        ic = diag([ic,ceros]);
        ic = ic(tril(true(size(ic))));
        ic  = ic';
    else
        ic = repmat(ic,1,params.InternalStates/2);
        ic = ic/sum(ic);
        ceros= zeros(1,params.ProblemDim/2);
        ic = diag([ic,ceros]);
        ic = ic(tril(true(size(ic))));
        ic  = ic';
       
    end
    
end
function ic = getThermalPopulation (params)
    m = 87.62*1.66054*10^-27; %Kg
    T = params.Temperature;
    Kb = 1.38064852 * 10^(-23);
    hbaraux = 1.0545718*10^-34; %Joules*Second
    kaux = (2*pi/689)*10^9;%Meters^-1
 
    
    
    p = (-(0:(params.pstates-1))) + params.p;
    K = -(p*hbaraux*kaux).^2/(m*2*Kb*T);    
    ic =  exp(K);
    
    
    if (params.Fp ==0 & params.F ==0)
        ic = ic/abs(sum(ic));
        ceros= zeros(1,params.pstates);
        ic = diag([ic,ceros]);
        ic = ic(tril(true(size(ic))));
        ic  = ic';
    else
        ic = repmat(ic,1,params.InternalStates/2);
        ic = ic/sum(ic);
        ceros= zeros(1,params.ProblemDim/2);
        ic = diag([ic,ceros]);
        ic = ic(tril(true(size(ic))));
        ic  = ic';
       
    end
    
end