classdef paramclass
   properties
       
        isSIunits ; %are we using SI units or hbar = 1, k = 1 , Gamma = 1 units;
        
        % Fundamental Constants
        m;
        hbar; 
        k; 
        Gamma; 
        mu; 
        Kb;
        
        savenameic
        % Atomic state parameters
        DeltaBGround;   %hertz 
        DeltaBexcited;   %hertz 
        Fp; 
        F;   
        
        % Laser parameters        
        Omega;  %hertz. Rabi frequency of laser   
        Poltab;  % Light polarization ( sigma+,pi,sigma- ) 

        % Sweep parameters
        modulationFrequency ;
        Ts; %seconds
        DeltaSweep; % hertz
        Sweepoffset ;
        Sweepasymetry; % Assymetry of the ramps, i.e how fast we ramp down.0.5 gives triangular ramps
        SWAPMODE; %-1 Inverted SWAP , 1 SWAP
        alpha;
        Nsweep;

        %Atomic sample properties
        Temperature;    %kelvin
        PopulationType = '1statev2';; %Defines the initial conditions
        p;  %hbar k
        
  
        % Relevant simulation data
        InternalStates;    %Number of internal states
        ProblemDim;        %Dimension of problem
        Tspam;             %Points to save during simulation
        SavedArray;        % Elements of density matrix to save during simulation
        auxMat;            % Auxiliary matrix. This should not be here
        pstates;           %Number of momentum states to use
        Evaluations;       %Number of evaluations to run for time calculation estimation
        OutputSimulation;  %Saved data from the simulation
        Savename;
        DataPath;          %Folder to save the data.
        polVector ;
        
        
        %To remove
        
   end
   methods

    function obj = paramclass()

   % Fundamental Constants
    obj.m= 87.62*1.66054*10^-27; %Kg
    obj.hbar = 1.0545718*10^-34; %Joules*Second
    obj.k = (2*pi/689)*10^9;%Meters^-1
    obj.Gamma = 2*pi*7.5*10^3; 
    obj.mu = (obj.hbar*obj.k^2)/(obj.Gamma);
    obj.Kb = 1.38064852*10^-23; %Joules/kelvin
    % Atomic state parameters        
    obj.DeltaBGround = 0*2*pi*10^3;  %hertz 
    obj.DeltaBexcited = 0*2*pi*10^3;  %hertz 
    obj.Fp =0;
    obj.F = 0;   


    % Laser parameters                
    obj.Omega = 150*2.0*pi*10^3;  %hertz
    Poltab = [ 0,1, 0];  % Light polarization ( sigma+,pi,sigma- ) 
    obj.Poltab = Poltab/ (sqrt(Poltab*Poltab'));

    % Sweep parameters
    obj.modulationFrequency = 0.01*10^6; %hertz
    obj.Ts = 1/obj.modulationFrequency ; %seconds
    obj.DeltaSweep = 2.2*2*pi*10^6;  % hertz
    obj.Sweepoffset = 0*0.45*obj.DeltaSweep;
    obj.Sweepasymetry = 0;
    obj.SWAPMODE = 1;
    obj.alpha = obj.DeltaSweep/obj.Ts;
    obj.Nsweep= 10;

    %Atomic sample properties
    obj.Temperature = 10^-3;   %kelvin
    obj.p = 60*obj.hbar*obj.k;  %hbar k

    % Relevant simulation data       
    obj.pstates = 11;
    obj.InternalStates = (obj.F + obj.Fp)*2 + 2;
    obj.ProblemDim =  obj.InternalStates*obj.pstates;
    obj.SavedArray= getvartosave(obj.ProblemDim);        
    obj.Evaluations =10^4; 




    %other Stuff
    obj.auxMat=tril(ones(obj.ProblemDim,obj.ProblemDim));        
    obj.isSIunits = true;
    obj.Tspam =linspace(0,obj.Ts*obj.Nsweep,1000);
    
    
    %to remove

  end
    function obj = getDimensionlessUnits(obj)
        if ( ~obj.isSIunits )
            return
        end
        
        obj.isSIunits = false;
        GammaRed =2*pi*7.5*10^3;        
        hbar = 1.0545718*10^-34; %Joules*Second;
        k = (2*pi/689)*10^9;%Meters^-1 
        mu = (hbar*k^2)/(GammaRed);
        Kb = 1.38064852*10^-23; %Joules/kelvin
        
        % Sweep parameters
        obj.modulationFrequency = obj.modulationFrequency/GammaRed; %hertz
        obj.Ts = obj.Ts*GammaRed;
        obj.DeltaSweep = obj.DeltaSweep/GammaRed;  
        obj.Sweepoffset = obj.Sweepoffset/GammaRed;
        obj.alpha = obj.alpha/GammaRed^2;

        % Laser parameters  
        obj.Omega =  obj.Omega/GammaRed;


        % Atomic state parameters
        obj.DeltaBGround =  obj.DeltaBGround/GammaRed;
        obj.DeltaBexcited = obj.DeltaBexcited/GammaRed;

        %Atomic sample properties
        obj.p = obj.p/hbar/k;  %Should b obj.Pstates/2 if using thermal ic.


        %Fundamental constants
        obj.Gamma = obj.Gamma/GammaRed;
        obj.hbar = obj.hbar/hbar;
        obj.k =obj.k/k;
        obj.m = obj.m/mu;
        obj.mu =obj.mu /mu;
        obj.Kb = obj.Kb/Kb; %Joules/kelvin



        obj.Tspam =linspace(0,obj.Ts*obj.Nsweep,1000);






  end
    function obj = getSIUnits(obj)
        if ( obj.isSIunits )
            return
        end
        obj.isSIunits = true;

        GammaRed =2*pi*7.5*10^3;        
        hbar = 1.0545718*10^-34; %Joules*Second;
        k = (2*pi/689)*10^9;%Meters^-1 
        mu = (hbar*k^2)/(GammaRed);
        obj.Kb = 1.38064852*10^-23; %Joules/kelvin
        %Fundamental constants

        obj.hbar =obj.hbar*hbar; %Joules*Second
        obj.k = obj.k*k;%Meters^-1 
        obj.Gamma =obj.Gamma*GammaRed  ;
        obj.mu =obj.mu * mu ;
        obj.m= obj.m*obj.mu; %Kg
        obj.Kb = 1.38064852*10^-23; %Joules/kelvin
        % Sweep parameters
        obj.modulationFrequency = obj.modulationFrequency*GammaRed; %hertz
        obj.Ts = obj.Ts/GammaRed;
        obj.DeltaSweep = obj.DeltaSweep*GammaRed;  
        obj.Sweepoffset = obj.Sweepoffset*GammaRed;
        obj.alpha = obj.alpha*GammaRed^2;

        % Laser parameters  
        obj.Omega =  obj.Omega*GammaRed;


        % Atomic state parameters
        obj.DeltaBGround =  obj.DeltaBGround*GammaRed;
        obj.DeltaBexcited = obj.DeltaBexcited*GammaRed;

        %Atomic sample properties
        obj.p = obj.p*hbar*k;  %Should b obj.Pstates/2 if using thermal ic.
        obj.Tspam =linspace(0,obj.Ts*obj.Nsweep,1000);
        obj = setStuffAtend(obj);


  end
    function obj = setPrAfig5Params(obj,Values)
         %Loads the data  fig 5 of
         %https://journals.aps.org/pra/abstract/10.1103/PhysRevA.98.023404
        obj = obj.getDimensionlessUnits();
        %Internal State parameters             
        obj.DeltaBGround =  0;
        obj.DeltaBexcited = 0;
        obj.F =0;
        obj.Fp = 0;
        obj.p = 20;
         
        
        %Sweep parameters
        obj.Ts = 1000;
        obj.Sweepoffset =0;        
        obj.DeltaSweep = 120;
        obj.Nsweep =10;
        obj.Omega = 1;
        obj.SWAPMODE = Values.SWAPMODE ; %Swap  ; %Swap  

        

        % Simulation properties

        obj.pstates= obj.p;
        obj.PopulationType = '1statev2';
     
        obj.Evaluations =10^4;
        obj = setStuffAtend(obj);
        obj.Gamma = Values.Gamma;
        
    end
    function obj = setPrAfig4Params(obj)
         %Loads the data  fig 4 of
         %https://journals.aps.org/pra/abstract/10.1103/PhysRevA.98.023404
        obj = obj.getDimensionlessUnits();
        
        obj.Evaluations =10^5;
        obj.Sweepoffset =0;
        obj.Nsweep =2;
        obj.pstates= 4;
        obj.Omega = 1;
        obj.Ts = 50;
        obj.p = obj.pstates;
        obj.DeltaSweep = 50;
        obj.alpha = 1;
        obj.Sweepoffset = 0;
        obj.m = 1;
        obj.Gamma = 0;
        obj.DeltaBGround =  0;
        obj.DeltaBexcited = 0;
        obj.PopulationType = '1State11';
        obj.Tspam =linspace(0,obj.Ts*obj.Nsweep,1000);
        obj = setStuffAtend(obj); 
    end
    function obj = setPrAfig4Params87(obj)
         %Loads the data  fig 4 of
         %https://journals.aps.org/pra/abstract/10.1103/PhysRevA.98.023404
        obj = obj.getDimensionlessUnits();
        
        obj.Evaluations =10^5;
%         obj.Sweepoffset =0;
        obj.Nsweep =2;
        obj.pstates= 4;
        obj.Omega = 20;
        obj.p = obj.pstates;
%         obj.Sweepoffset = 0;
        obj.Poltab = [1,1,1]/norm([1,1,1]);
        obj.m = 1;
        obj.Gamma = 0;
        obj.DeltaBGround =  0;
        obj.DeltaBexcited = 120/7.5;
        obj.PopulationType = '1State11';
        obj.Tspam =linspace(0,obj.Ts*obj.Nsweep,1000);
        obj = setStuffAtend(obj); 
    end
    function obj = set87Srparams(obj)
        obj = obj.getSIUnits();
        
        obj.DeltaBGround = 0*2*pi*10^3;  %hertz 
        obj.DeltaBexcited = 200*2*pi*10^3;  %hertz %Corresponding to a magnetic field strenght of 2.4 Gauss
        obj.Fp =4.5;
        obj.F = 4.5; 
        obj.pstates  = 11;
        obj.Sweepoffset = 0.45*obj.DeltaSweep;
        
        
        obj = obj.getDimensionlessUnits();
        obj = setStuffAtend(obj) ; 
    end
    function obj = set87SrModFreq(obj,values)
        obj = set87Srparams(obj);
        obj = obj.getSIUnits();
        


        
        
        obj.modulationFrequency =values.modulationFrequency;
        obj.Sweepasymetry = values.Sweepasymetry;
        obj.Nsweep = values.Nsweep;
        obj.SWAPMODE = values.SWAPMODE;
        obj.Omega = values.Omega;
        obj.p = values.p*obj.hbar*obj.k;
        
        obj.Ts = (1/obj.modulationFrequency );
        
        Poltab = [ 1,0, 1];  % Light polarization ( sigma+,pi,sigma- ) 
        obj.Poltab = Poltab/ (sqrt(Poltab*Poltab'));
        
        obj = setStuffAtend(obj);
        obj = obj.getDimensionlessUnits();
        
    end
    function obj = set87CoolingParams (obj,values)
        
        obj = set87Srparams(obj);
        obj = obj.getSIUnits();

        obj.modulationFrequency =values.modulationFrequency;
        obj.Sweepasymetry = values.Sweepasymetry;
        obj.Nsweep = values.Nsweep;
        obj.SWAPMODE = values.SWAPMODE;
        obj.Omega = values.Omega;
        obj.p = values.p*obj.hbar*obj.k;
        obj.pstates = values.pstates;
        obj.Ts = (1/obj.modulationFrequency );
        
        Poltab = values.Poltab;  % Light polarization ( sigma+,pi,sigma- ) 
        obj.Poltab = Poltab/ (sqrt(Poltab*Poltab'));
        
        obj.Evaluations = 1e2;
        obj = setStuffAtend(obj);
        obj = obj.getDimensionlessUnits();
    end
    
    function obj  = setBosonicSrparams(obj)
        obj = obj.getDimensionlessUnits();
        %Internal State parameters             
        obj.DeltaBGround =  0;
        obj.DeltaBexcited = 0;
        obj.F =0;
        obj.Fp = 0;
        obj.p = 10;   

        %Sweep parameters
%         obj.Ts = 1000;%4.7124
        obj.Sweepoffset =0;        
        %obj.DeltaSweep = 1000;
        obj.Nsweep =2;

        %Laser parameters
        obj.Omega = 20; %36

        % Simulation properties
        obj.pstates =20; 
        obj.PopulationType = '1State11';
        obj.Evaluations =10^4;

        obj = setStuffAtend(obj);
        
        
        
    end
    function obj = setTestparams(obj,values) 

    
        obj = obj.getSIUnits();
        obj.DeltaBGround = 0*2*pi*10^3;  %hertz 
        obj.DeltaBexcited = 120*2*pi*10^3;  %hertz 
        obj.Fp =values.Fp;
        obj.F = values.F; 
        obj.pstates = values.pstates;
        
        obj = obj.getDimensionlessUnits();
        obj = setStuffAtend(obj) ; 
    
    end
    
    function plotSweeps(obj)
        figure
        obj = obj.getSIUnits();
        hbar =obj.hbar;
        k = obj.k;
        m = obj.m;

        bare = zeros(size(obj.Tspam));
        Red =@(p) ( (p-hbar*k).^2 - p.^2 )/(2*m*hbar)*ones(size(obj.Tspam));       
        Blue =@(p) ((p+hbar*k).^2 - p.^2)/(2*m*hbar)*ones(size(obj.Tspam));


        counter = 0;
        y = zeros(size(obj.Tspam));
        for i  = (obj.Tspam)
        counter = counter + 1;
        y(1,counter) = Sweep(i,obj);
        end

        hold on
        t = obj.Tspam;
        p = obj.p;

        plot(t,bare,t,Red(p)/2/pi,t,Blue(p)/2/pi)
        plot(t,y/2/pi)
        xlabel('time [s]')
        ylabel('Frequency MHz')
        hold off
    end

    function plotInternalStates(obj)
            obj = obj.getSIUnits();
            figure
            Energy = GetInternalStateEnergies (obj);
            
            plotMat = Energy'*ones(size(obj.Tspam ) );
            toDelete = (1:(obj.F*2+1));
            plotMat(toDelete,:) = [];
            t = obj.Tspam;
            hold on

            plot(t,plotMat/2/pi)
            plot (t,Sweep(obj.Tspam,obj)/2/pi)
            hold off
    end
    function obj = setStuffAtend(obj)
        obj.Tspam =linspace(0,obj.Ts*obj.Nsweep,1000);
        obj.InternalStates = (obj.F + obj.Fp)*2 + 2;
        obj.alpha = obj.DeltaSweep/obj.Ts;
        obj.ProblemDim =  obj.InternalStates*obj.pstates;
        obj.auxMat=tril(ones(obj.ProblemDim,obj.ProblemDim));    
        obj.SavedArray = getvartosave(obj.ProblemDim); 
        
        

    end
    
    function plotResult(obj)
            figure();
            obj = getDimensionlessUnits(obj);
            P = obj.OutputSimulation;
            plotarray = zeros(obj.ProblemDim,1);
            hold on
            Operatorss  =OperatorClass(obj)
            Pmat = Operatorss.Pmat;
            Pmatv = diag(Pmat);
            legendv={};
            for ii = 1:( obj.ProblemDim )
                if (plotarray(ii))
                    time =P.x;
                    y = P.y (:,ii);
                    plot(time,y)
                    if (ii>obj.ProblemDim/2)
                        legendv= [legendv, {['|e',num2str(Pmatv(ii)),'hbar*k>']}];
                    else
                        legendv= [legendv, {['|g',num2str(Pmatv(ii)),'hbar*k>']}];
                    end
                end
            end

            hold off
            ylabel(' Popuation probability ') 
            legend (legendv)
            legend('Location','best')
            ax1 = gca; % current axes
            ExitedMAt = diag([zeros(size(Pmat,2)/2,1);ones(size(Pmat,2)/2,1)]);
            %Plots average momentum over time
            Rho = @(t) diag(P.y(t,:));
            Pavg = @(t)  trace(Rho(t)*Pmat);
            Pexited = @(t)trace(Rho(t)*ExitedMAt);
            index = size( P.y,1);
            for i = 1:index
            Yval ( i ) = Pavg( i ) ;
            Yval2 (i) = Pexited(i);
            
            end

            Times  = P.x;
            hold on
            plot(Times,Yval2)
            plot(Times,1-Yval2)
            hold off
            ax1_pos = ax1.Position; % position of first axes
            ax2 = axes('Position',ax1_pos,...
            'YAxisLocation','right',...
            'Color','none');

            line(Times,Yval,'Parent',ax2,'Color','k')

            xlabel(' Time (s)') 
            ylabel(' Paverage (hbar*kred) ') 

            hold off
    end
    function plotMomentum(obj)
    figure;


    %%Plot population of states
    hold on
    P = obj.OutputSimulation;
    
    ylabel(' Popuation probability ') 
    ax1 = gca; % current axes

    Pmat = getPmat(obj);
    %Plots average momentum over time
    Rho = @(t) diag(P.y(t,:));
    Pavg = @(t)  trace(Rho(t)*Pmat);
    index = size( P.y,1);
    for i = 1:index
        Yval ( i ) = Pavg( i ) ;
    end
    Times  = obj.Tspam(1:999);

    line(Times,Yval,'Color','k')
    xlabel(' Sweeps ') 
    ylabel(' Paverage (hbar*kred) ') 
    hold off

    end
    
    function [force] =  expectedForce (params,OmegaEffective)
    params = params.getSIUnits();
    Omega  = params.Omega/2;
    Delta= params.DeltaSweep; % hertz
    Freq = 1/params.Ts;
    force = Freq.*(1-exp(-((cte*OmegaEffective).^2)./(Delta.*Freq)))
end
    
    function saveParams(obj)
     saveVar = obj;
     target = obj.Savename;
     display(['Saved',target]);
     if (exist(target, 'file' )== 2   )
         error('file already exisit')
     else
        save(target,'saveVar');
     end
    end

   end
end