(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     17110,        493]
NotebookOptionsPosition[     12961,        409]
NotebookOutlinePosition[     13342,        425]
CellTagsIndexPosition[     13299,        422]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.797185544790286*^9, 
  3.7971855466829677`*^9}},ExpressionUUID->"eabaa51b-1ee7-43b7-867b-\
ec689a28ac88"],

Cell[CellGroupData[{

Cell["Calculating MOT peak density", "Title",
 CellChangeTimes->{{3.797670237531146*^9, 
  3.7976702421649475`*^9}},ExpressionUUID->"f4e12dab-5b8a-45eb-8d64-\
de2c84e6238e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mm", " ", "=", " ", 
  RowBox[{"Quantity", "[", 
   RowBox[{"1", ",", "\"\<Millimeters\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7976701697409286`*^9, 
  3.7976701812063856`*^9}},ExpressionUUID->"10c9dfb7-52ee-469e-a0f2-\
3460abe653ce"],

Cell[BoxData[
 TemplateBox[{"1","\"mm\"","millimeters","\"Millimeters\""},
  "Quantity"]], "Output",
 CellChangeTimes->{3.797670477320595*^9, 3.7976705100661106`*^9, 
  3.797670711893099*^9, 
  3.8220571764211507`*^9},ExpressionUUID->"e948bb25-7cc8-4cef-8938-\
dd4b6d46da69"]
}, Open  ]],

Cell[CellGroupData[{

Cell["87 Sr density", "Section",
 CellChangeTimes->{{3.797185552064497*^9, 
  3.7971855556824474`*^9}},ExpressionUUID->"be3b85d5-a3cc-4621-bec9-\
e36410770dbe"],

Cell[CellGroupData[{

Cell["Input Mot Parameters:", "Subsection",
 CellChangeTimes->{{3.797670248703967*^9, 
  3.797670261826239*^9}},ExpressionUUID->"12af65e6-585f-444b-8eac-\
d2731807bfb9"],

Cell[CellGroupData[{

Cell["Mot dimensions and total atom number", "Subsubsection",
 CellChangeTimes->{{3.7976702658887787`*^9, 
  3.797670280630699*^9}},ExpressionUUID->"f6c9f6fa-2e66-4bdc-b264-\
679c4473abe0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]y", "=", " ", 
   RowBox[{"0.4225", "*", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]x", "=", 
   RowBox[{"1.2843", "*", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]z", "=", "\[Sigma]x"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ni", " ", "=", " ", 
   RowBox[{"3.7", "*", 
    SuperscriptBox["10", "6"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7971847633175936`*^9, 3.7971849385609183`*^9}, {
  3.79718499576163*^9, 3.79718500428864*^9}, {3.797185044219271*^9, 
  3.7971850576581244`*^9}, {3.797185104885418*^9, 3.7971851166759167`*^9}, {
  3.797670143895894*^9, 3.797670229089757*^9}, {3.7976704153529844`*^9, 
  3.797670469679309*^9}},ExpressionUUID->"fd055e7c-74f6-4d22-a2ab-\
693972b67dc3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]Ni", " ", "=", " ", 
  RowBox[{"0.06", "*", 
   SuperscriptBox["10", "6"]}]}]], "Input",
 CellChangeTimes->{{3.7976706918595514`*^9, 
  3.7976706943292294`*^9}},ExpressionUUID->"e91abc1a-5a1a-4485-9fe4-\
e82f94f6f0a6"],

Cell[BoxData["60000.`"], "Output",
 CellChangeTimes->{3.7976707123005295`*^9, 
  3.8220571764554806`*^9},ExpressionUUID->"1dbcddbd-0998-4089-b04c-\
116941e079eb"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assume Gaussian distribution and calculate peak density.", "Subsection",
 CellChangeTimes->{{3.7976704550899935`*^9, 
  3.7976704860199995`*^9}},ExpressionUUID->"f5b5b265-6f66-462a-963f-\
193881f69109"],

Cell[BoxData["10.975630577318746`"], "Output",
 CellChangeTimes->{
  3.7976704446067047`*^9},ExpressionUUID->"9214a869-1cdb-4c22-891c-\
de2ff82015cd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", " ", 
    RowBox[{
     RowBox[{"Exp", "[", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "*", "mm"}], ")"}], "2"]}], 
       RowBox[{"2", "*", 
        SuperscriptBox["\[Sigma]x", "2"]}]], "]"}], "*", 
     RowBox[{"Exp", "[", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "*", "mm"}], ")"}], "2"]}], 
       RowBox[{"2", "*", 
        SuperscriptBox["\[Sigma]y", "2"]}]], "]"}], "*", 
     RowBox[{"Exp", "[", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "*", "mm"}], ")"}], "2"]}], 
       RowBox[{"2", "*", 
        SuperscriptBox["\[Sigma]z", "2"]}]], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cte", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"n", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.7976704722379274`*^9},ExpressionUUID->"a05dccb5-07c6-451e-a39c-\
f8f02865d359"],

Cell[BoxData["10.975630577318746`"], "Output",
 CellChangeTimes->{3.797670480204052*^9, 3.7976705124775925`*^9, 
  3.7976707138898582`*^9, 
  3.822057177658057*^9},ExpressionUUID->"79dc179b-4b80-4738-9817-\
2dfa9693494e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MaxDensity", " ", "=", " ", 
  RowBox[{"Ni", "/", "cte", " ", 
   RowBox[{"(*", 
    RowBox[{"atoms", " ", ",", " ", 
     RowBox[{"per", " ", 
      SuperscriptBox["mm", "3"]}]}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.797185119899129*^9, 3.7971851284663153`*^9}, 
   3.7976704330593367`*^9, {3.7976704909285145`*^9, 
   3.797670496786606*^9}},ExpressionUUID->"b3d18cf7-5ab5-4317-b581-\
bdac526bc05e"],

Cell[BoxData["337110.47159751237`"], "Output",
 CellChangeTimes->{3.7976707142203035`*^9, 
  3.822057177742896*^9},ExpressionUUID->"9391f20f-202d-47f4-91e0-\
f76400d25969"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]MaxDensity", " ", "=", " ", 
  RowBox[{"\[CapitalDelta]Ni", "/", "cte"}]}]], "Input",ExpressionUUID->\
"1f0aab8d-cde5-4c21-b3e7-0ec97bc46e4d"],

Cell[BoxData["5466.656296175876`"], "Output",
 CellChangeTimes->{{3.797670497508844*^9, 3.7976705128384695`*^9}, 
   3.797670714442675*^9, 
   3.822057177754586*^9},ExpressionUUID->"4154ed9f-6f7d-41ad-a24c-\
3926785fa951"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7971851337180986`*^9, 3.7971851590751257`*^9}, 
   3.797670490265255*^9},ExpressionUUID->"aaaac58e-6be9-412e-83ec-\
d9ef49860c79"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7971849188057175`*^9, 3.797185013390506*^9}, {
   3.7971850644183755`*^9, 3.7971850693246164`*^9}, {3.7976704258576584`*^9, 
   3.7976704262291794`*^9}, 
   3.7976705010549245`*^9},ExpressionUUID->"eadf3514-2092-4b5f-af9b-\
db88123b0502"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["88 Sr density", "Section",
 CellChangeTimes->{{3.797185552064497*^9, 3.7971855556824474`*^9}, {
  3.7976705196044493`*^9, 
  3.7976705201295595`*^9}},ExpressionUUID->"2f01ca24-6faf-4091-8883-\
1d8313626a71"],

Cell[CellGroupData[{

Cell["Input Mot Parameters:", "Subsection",
 CellChangeTimes->{{3.797670248703967*^9, 
  3.797670261826239*^9}},ExpressionUUID->"5d6a2705-ee6d-49f2-ab6f-\
88f1f7a9926b"],

Cell[CellGroupData[{

Cell["Mot dimensions and total atom number", "Subsubsection",
 CellChangeTimes->{{3.7976702658887787`*^9, 
  3.797670280630699*^9}},ExpressionUUID->"1891f1e9-20ed-4518-93b6-\
34d58fa00bda"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]y", "=", " ", 
   RowBox[{"0.274", "*", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]x", "=", 
   RowBox[{"1.756", "*", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]z", "=", "\[Sigma]x"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ni", " ", "=", " ", 
   RowBox[{"9.7", "*", 
    SuperscriptBox["10", "7"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalDelta]Ni", " ", "=", " ", 
  RowBox[{"0.4", "*", 
   SuperscriptBox["10", "7"]}]}]}], "Input",
 CellChangeTimes->{{3.7971847633175936`*^9, 3.7971849385609183`*^9}, {
  3.79718499576163*^9, 3.79718500428864*^9}, {3.797185044219271*^9, 
  3.7971850576581244`*^9}, {3.797185104885418*^9, 3.7971851166759167`*^9}, {
  3.797670143895894*^9, 3.797670229089757*^9}, {3.7976704153529844`*^9, 
  3.797670469679309*^9}, {3.797670539772373*^9, 3.7976705469892206`*^9}, {
  3.7976706185582266`*^9, 
  3.797670633639478*^9}},ExpressionUUID->"11003c8a-a8c4-4f81-9281-\
9314efefa0f1"],

Cell[BoxData["4.`*^6"], "Output",
 CellChangeTimes->{3.7976707147690487`*^9, 
  3.8220571777835617`*^9},ExpressionUUID->"7ad69cf6-6f28-481d-bb91-\
8977cef07058"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assume Gaussian distribution and calculate peak density.", "Subsection",
 CellChangeTimes->{{3.7976704550899935`*^9, 
  3.7976704860199995`*^9}},ExpressionUUID->"f36dd48a-6a2b-49de-8466-\
c7b27cc78d55"],

Cell[BoxData["10.975630577318746`"], "Output",
 CellChangeTimes->{
  3.7976704446067047`*^9},ExpressionUUID->"e8783977-5cb9-444a-aa78-\
03b6f6a33213"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", " ", 
    RowBox[{
     RowBox[{"Exp", "[", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "*", "mm"}], ")"}], "2"]}], 
       RowBox[{"2", "*", 
        SuperscriptBox["\[Sigma]x", "2"]}]], "]"}], "*", 
     RowBox[{"Exp", "[", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"y", "*", "mm"}], ")"}], "2"]}], 
       RowBox[{"2", "*", 
        SuperscriptBox["\[Sigma]y", "2"]}]], "]"}], "*", 
     RowBox[{"Exp", "[", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "*", "mm"}], ")"}], "2"]}], 
       RowBox[{"2", "*", 
        SuperscriptBox["\[Sigma]z", "2"]}]], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"cte", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"n", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.7976704722379274`*^9, {3.7976705687237644`*^9, 
   3.7976705728532925`*^9}},ExpressionUUID->"10c90159-a202-4dbf-a843-\
45151b3b387c"],

Cell[BoxData["13.306670055484517`"], "Output",
 CellChangeTimes->{3.797670480204052*^9, 3.7976705124775925`*^9, 
  3.7976705911334267`*^9, 3.797670716995897*^9, 
  3.8220571784692383`*^9},ExpressionUUID->"f8ff94f6-238b-4b3b-9417-\
28adaf8295b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MaxDensity", " ", "=", " ", 
  RowBox[{"Ni", "/", "cte", " ", 
   RowBox[{"(*", 
    RowBox[{"atoms", " ", ",", " ", 
     RowBox[{"per", " ", 
      SuperscriptBox["mm", "3"]}]}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.797185119899129*^9, 3.7971851284663153`*^9}, 
   3.7976704330593367`*^9, {3.7976704909285145`*^9, 
   3.797670496786606*^9}},ExpressionUUID->"0eca0464-ba0c-4c7b-9d93-\
0aae5519f063"],

Cell[BoxData["7.289577301875024`*^6"], "Output",
 CellChangeTimes->{3.7976707174073486`*^9, 
  3.822057178480296*^9},ExpressionUUID->"dfb6ff2b-fee5-4aa3-bfe7-\
58eb93b823f8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]MaxDensity", " ", "=", " ", 
  RowBox[{"\[CapitalDelta]Ni", "/", "cte"}]}]], "Input",ExpressionUUID->\
"f5a440e7-1a22-43b8-8a30-c8a554857ad9"],

Cell[BoxData["300601.1258505165`"], "Output",
 CellChangeTimes->{{3.797670497508844*^9, 3.7976705128384695`*^9}, 
   3.7976705931425223`*^9, 3.797670647394554*^9, 3.7976707176438923`*^9, 
   3.8220571784951553`*^9},ExpressionUUID->"0dddff82-2f43-427b-851f-\
3483066268e9"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7971851337180986`*^9, 3.7971851590751257`*^9}, 
   3.797670490265255*^9},ExpressionUUID->"e1d5c897-b0ca-464f-9dbc-\
947c84a20394"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7971849188057175`*^9, 3.797185013390506*^9}, {
   3.7971850644183755`*^9, 3.7971850693246164`*^9}, {3.7976704258576584`*^9, 
   3.7976704262291794`*^9}, 
   3.7976705010549245`*^9},ExpressionUUID->"07aa6db1-998a-4955-b65a-\
9b93c2ebb7bf"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1904, 997},
WindowMargins->{{1017, Automatic}, {Automatic, 642}},
Magnification:>1.4 Inherited,
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 154, 3, 40, "Input",ExpressionUUID->"eabaa51b-1ee7-43b7-867b-ec689a28ac88"],
Cell[CellGroupData[{
Cell[737, 27, 173, 3, 135, "Title",ExpressionUUID->"f4e12dab-5b8a-45eb-8d64-de2c84e6238e"],
Cell[CellGroupData[{
Cell[935, 34, 267, 6, 40, "Input",ExpressionUUID->"10c9dfb7-52ee-469e-a0f2-3460abe653ce"],
Cell[1205, 42, 275, 6, 52, "Output",ExpressionUUID->"e948bb25-7cc8-4cef-8938-dd4b6d46da69"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1517, 53, 160, 3, 92, "Section",ExpressionUUID->"be3b85d5-a3cc-4621-bec9-e36410770dbe"],
Cell[CellGroupData[{
Cell[1702, 60, 169, 3, 75, "Subsection",ExpressionUUID->"12af65e6-585f-444b-8eac-d2731807bfb9"],
Cell[CellGroupData[{
Cell[1896, 67, 189, 3, 62, "Subsubsection",ExpressionUUID->"f6c9f6fa-2e66-4bdc-b264-679c4473abe0"],
Cell[2088, 72, 807, 18, 125, "Input",ExpressionUUID->"fd055e7c-74f6-4d22-a2ab-693972b67dc3"],
Cell[CellGroupData[{
Cell[2920, 94, 257, 6, 40, "Input",ExpressionUUID->"e91abc1a-5a1a-4485-9fe4-e82f94f6f0a6"],
Cell[3180, 102, 162, 3, 46, "Output",ExpressionUUID->"1dbcddbd-0998-4089-b04c-116941e079eb"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3403, 112, 208, 3, 75, "Subsection",ExpressionUUID->"f5b5b265-6f66-462a-963f-193881f69109"],
Cell[3614, 117, 150, 3, 46, "Output",ExpressionUUID->"9214a869-1cdb-4c22-891c-de2ff82015cd"],
Cell[CellGroupData[{
Cell[3789, 124, 1537, 49, 136, "Input",ExpressionUUID->"a05dccb5-07c6-451e-a39c-f8f02865d359"],
Cell[5329, 175, 221, 4, 46, "Output",ExpressionUUID->"79dc179b-4b80-4738-9817-2dfa9693494e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5587, 184, 431, 10, 43, "Input",ExpressionUUID->"b3d18cf7-5ab5-4317-b581-bdac526bc05e"],
Cell[6021, 196, 172, 3, 46, "Output",ExpressionUUID->"9391f20f-202d-47f4-91e0-f76400d25969"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6230, 204, 181, 3, 40, "Input",ExpressionUUID->"1f0aab8d-cde5-4c21-b3e7-0ec97bc46e4d"],
Cell[6414, 209, 222, 4, 46, "Output",ExpressionUUID->"4154ed9f-6f7d-41ad-a24c-3926785fa951"]
}, Open  ]],
Cell[6651, 216, 179, 3, 40, "Input",ExpressionUUID->"aaaac58e-6be9-412e-83ec-d9ef49860c79"],
Cell[6833, 221, 287, 5, 40, "Input",ExpressionUUID->"eadf3514-2092-4b5f-af9b-db88123b0502"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7169, 232, 213, 4, 92, "Section",ExpressionUUID->"2f01ca24-6faf-4091-8883-1d8313626a71"],
Cell[CellGroupData[{
Cell[7407, 240, 169, 3, 75, "Subsection",ExpressionUUID->"5d6a2705-ee6d-49f2-ab6f-88f1f7a9926b"],
Cell[CellGroupData[{
Cell[7601, 247, 189, 3, 62, "Subsubsection",ExpressionUUID->"1891f1e9-20ed-4518-93b6-34d58fa00bda"],
Cell[CellGroupData[{
Cell[7815, 254, 1034, 23, 153, "Input",ExpressionUUID->"11003c8a-a8c4-4f81-9281-9314efefa0f1"],
Cell[8852, 279, 161, 3, 46, "Output",ExpressionUUID->"7ad69cf6-6f28-481d-bb91-8977cef07058"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9074, 289, 208, 3, 75, "Subsection",ExpressionUUID->"f36dd48a-6a2b-49de-8466-c7b27cc78d55"],
Cell[9285, 294, 150, 3, 46, "Output",ExpressionUUID->"e8783977-5cb9-444a-aa78-03b6f6a33213"],
Cell[CellGroupData[{
Cell[9460, 301, 1591, 50, 136, "Input",ExpressionUUID->"10c90159-a202-4dbf-a843-45151b3b387c"],
Cell[11054, 353, 245, 4, 46, "Output",ExpressionUUID->"f8ff94f6-238b-4b3b-9417-28adaf8295b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11336, 362, 431, 10, 43, "Input",ExpressionUUID->"0eca0464-ba0c-4c7b-9d93-0aae5519f063"],
Cell[11770, 374, 174, 3, 46, "Output",ExpressionUUID->"dfb6ff2b-fee5-4aa3-bfe7-58eb93b823f8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11981, 382, 181, 3, 40, "Input",ExpressionUUID->"f5a440e7-1a22-43b8-8a30-c8a554857ad9"],
Cell[12165, 387, 272, 4, 46, "Output",ExpressionUUID->"0dddff82-2f43-427b-851f-3483066268e9"]
}, Open  ]],
Cell[12452, 394, 179, 3, 40, "Input",ExpressionUUID->"e1d5c897-b0ca-464f-9dbc-947c84a20394"],
Cell[12634, 399, 287, 5, 40, "Input",ExpressionUUID->"07aa6db1-998a-4955-b65a-9b93c2ebb7bf"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

